@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdedit_audio.h,v 1.5 2007-12-29 18:16:10 fredg Exp $
+//      $Id: rdedit_audio.h,v 1.9.6.1 2012/05/07 23:31:59 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -47,6 +47,8 @@
 #include <rdcut.h>
 #include <rdcae.h>
 #include <rduser.h>
+#include <rdstation.h>
+#include <rdpeaksexport.h>
 
 //
 // Widget Settings
@@ -74,7 +76,7 @@ class RDEditAudio : public QDialog
   Q_OBJECT
  public:
   RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
-	      int card,int port,int preroll,int trim_level,
+	      RDStation *station,int card,int port,int preroll,int trim_level,
 	      QWidget *parent=0,const char *name=0);
   ~RDEditAudio();
   QSize sizeHint() const;
@@ -139,7 +141,7 @@ class RDEditAudio : public QDialog
   void PreRoll(int cursor,RDEditAudio::CuePoints);
   bool PositionCursor(int cursor=0,bool relative=false);
   void ValidateMarkers();
-  void SaveMarkers();
+  bool SaveMarkers();
   void LoopRegion(int cursor0,int cursor1);
   void UpdateCounters();
   void DrawMaps();
@@ -155,7 +157,10 @@ class RDEditAudio : public QDialog
   void CenterDisplay();
   int GetTime(int samples);
   RDCut *edit_cut;
-  RDWaveFile *edit_wave;
+  RDPeaksExport *edit_peaks;
+  unsigned edit_sample_rate;
+  unsigned edit_sample_length;
+  unsigned edit_channels;
   QPopupMenu *edit_menu;
   QScrollBar *edit_hscroll;
   QImage edit_left_ref_image;
@@ -215,6 +220,8 @@ class RDEditAudio : public QDialog
   int edit_port;
   int edit_preroll;
   RDCae *edit_cae;
+  RDStation *edit_station;
+  RDUser *edit_user;
 };
 
 
