@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog.cpp,v 1.18.2.1 2008-12-08 19:00:23 fredg Exp $
+//      $Id: rdlog.cpp,v 1.23 2011/12/22 23:58:51 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -365,14 +365,16 @@ bool RDLog::isReady() const
 }
 
 
-void RDLog::remove() const
+bool RDLog::remove(RDStation *station,RDUser *user) const
 {
   QString sql;
   RDSqlQuery *q;
   QString name=log_name;
 
   name.replace(" ","_");
-  removeTracks();
+  if(removeTracks(station,user)<0) {
+    return false;
+  }
   sql=QString().sprintf("drop table `%s_LOG`",(const char *)name);
   q=new RDSqlQuery(sql);
   delete q;
@@ -380,6 +382,7 @@ void RDLog::remove() const
 			(const char *)log_name);
   q=new RDSqlQuery(sql);
   delete q;
+  return true;
 }
 
 
@@ -392,7 +395,7 @@ void RDLog::updateTracks()
   QString name=log_name;
   
   name.replace(" ","_");
-  sql=QString().sprintf("select NUMBER from CART where OWNER=\"%s_LOG\"",
+  sql=QString().sprintf("select NUMBER from CART where OWNER=\"%s\"",
 			(const char *)log_name);
   q=new RDSqlQuery(sql);
   completed=q->size();
@@ -414,21 +417,24 @@ void RDLog::updateTracks()
 }
 
 
-unsigned RDLog::removeTracks() const
+int RDLog::removeTracks(RDStation *station,RDUser *user) const
 {
   QString sql;
   RDSqlQuery *q;
-  unsigned count=0;
+  int count=0;
   RDCart *cart;
 
   QString owner=log_name;
   owner.replace(" ","_");
-  sql=QString().sprintf("select NUMBER from CART where OWNER=\"%s_LOG\"",
+  sql=QString().sprintf("select NUMBER from CART where OWNER=\"%s\"",
 			(const char *)owner);
   q=new RDSqlQuery(sql);
   while(q->next()) {
     cart=new RDCart(q->value(0).toUInt());
-    cart->remove();
+    if(!cart->remove(station,user)) {
+      delete cart;
+      return -1;
+    }
     delete cart;
     count++;
   }
