@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdreport.cpp,v 1.23.2.3 2009/08/08 16:26:05 cvs Exp $
+//      $Id: rdreport.cpp,v 1.27.4.7 2013/01/22 20:59:39 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,8 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <qobject.h>
+
 #include <rdconf.h>
 #include <rdreport.h>
 #include <rdcreate_log.h>
@@ -27,6 +29,7 @@
 #include <rdescape_string.h>
 #include <rddb.h>
 #include <rdescape_string.h>
+#include <rddatedecode.h>
 
 RDReport::RDReport(const QString &rptname,QObject *parent,const char *name)
 {
@@ -41,7 +44,7 @@ QString RDReport::name() const
 }
 
 
-bool RDReport::exists()
+bool RDReport::exists() const
 {
   RDSqlQuery *q=new RDSqlQuery(QString().sprintf("select NAME from REPORTS\
                                                 where NAME=\"%s\"",
@@ -56,102 +59,102 @@ bool RDReport::exists()
 }
 
 
-QString RDReport::description()
+QString RDReport::description() const
 {
   return RDGetSqlValue("REPORTS","NAME",report_name,"DESCRIPTION").toString();
 }
 
 
-void RDReport::setDescription(const QString &desc)
+void RDReport::setDescription(const QString &desc) const
 {
   SetRow("DESCRIPTION",desc);
 }
 
 
-RDReport::ExportFilter RDReport::filter()
+RDReport::ExportFilter RDReport::filter() const
 {
   return (RDReport::ExportFilter)RDGetSqlValue("REPORTS","NAME",report_name,
 					      "EXPORT_FILTER").toInt();
 }
 
 
-void RDReport::setFilter(ExportFilter filter)
+void RDReport::setFilter(ExportFilter filter) const
 {
   SetRow("EXPORT_FILTER",(int)filter);
 }
 
 
-QString RDReport::exportPath(ExportOs ostype)
+QString RDReport::exportPath(ExportOs ostype) const
 {
   return RDGetSqlValue("REPORTS","NAME",report_name,OsFieldName(ostype)).
     toString();
 }
 
 
-void RDReport::setExportPath(ExportOs ostype,const QString &path)
+void RDReport::setExportPath(ExportOs ostype,const QString &path) const
 {
   SetRow(OsFieldName(ostype),path);
 }
 
 
-bool RDReport::exportTypeEnabled(ExportType type)
+bool RDReport::exportTypeEnabled(ExportType type) const
 {
   return RDBool(RDGetSqlValue("REPORTS","NAME",report_name,
 			    TypeFieldName(type,false)).toString());
 }
 
 
-void RDReport::setExportTypeEnabled(ExportType type,bool state)
+void RDReport::setExportTypeEnabled(ExportType type,bool state) const
 {
   SetRow(TypeFieldName(type,false),RDYesNo(state));
 }
 
 
-bool RDReport::exportTypeForced(ExportType type)
+bool RDReport::exportTypeForced(ExportType type) const
 {
   return RDBool(RDGetSqlValue("REPORTS","NAME",report_name,
 			    TypeFieldName(type,true)).toString());
 }
 
 
-void RDReport::setExportTypeForced(ExportType type,bool state)
+void RDReport::setExportTypeForced(ExportType type,bool state) const
 {
   SetRow(TypeFieldName(type,true),RDYesNo(state));
 }
 
 
-QString RDReport::stationId()
+QString RDReport::stationId() const
 {
   return RDGetSqlValue("REPORTS","NAME",report_name,"STATION_ID").toString();
 }
 
 
-void RDReport::setStationId(const QString &id)
+void RDReport::setStationId(const QString &id) const
 {
   SetRow("STATION_ID",id);
 }
 
 
-unsigned RDReport::cartDigits()
+unsigned RDReport::cartDigits() const
 {
   return RDGetSqlValue("REPORTS","NAME",report_name,"CART_DIGITS").toUInt();
 }
 
   
-void RDReport::setCartDigits(unsigned num)
+void RDReport::setCartDigits(unsigned num) const
 {
   SetRow("CART_DIGITS",num);
 }
 
 
-bool RDReport::useLeadingZeros()
+bool RDReport::useLeadingZeros() const
 {
   return RDBool(RDGetSqlValue("REPORTS","NAME",report_name,"USE_LEADING_ZEROS").
 	       toString());
 }
 
 
-void RDReport::setUseLeadingZeros(bool state)
+void RDReport::setUseLeadingZeros(bool state) const
 {
   SetRow("USE_LEADING_ZEROS",state);
 }
@@ -163,7 +166,7 @@ int RDReport::linesPerPage() const
 }
 
 
-void RDReport::setLinesPerPage(int lines)
+void RDReport::setLinesPerPage(int lines) const
 {
   SetRow("LINES_PER_PAGE",lines);
 }
@@ -175,7 +178,7 @@ QString RDReport::serviceName() const
 }
 
 
-void RDReport::setServiceName(const QString &name)
+void RDReport::setServiceName(const QString &name) const
 {
   SetRow("SERVICE_NAME",name);
 }
@@ -188,7 +191,7 @@ RDReport::StationType RDReport::stationType() const
 }
 
 
-void RDReport::setStationType(RDReport::StationType type)
+void RDReport::setStationType(RDReport::StationType type) const
 {
   SetRow("STATION_TYPE",(int)type);
 }
@@ -201,7 +204,7 @@ QString RDReport::stationFormat() const
 }
 
 
-void RDReport::setStationFormat(const QString &fmt)
+void RDReport::setStationFormat(const QString &fmt) const
 {
   SetRow("STATION_FORMAT",fmt);
 }
@@ -214,12 +217,25 @@ bool RDReport::filterOnairFlag() const
 }
 
 
-void RDReport::setFilterOnairFlag(bool state)
+void RDReport::setFilterOnairFlag(bool state) const
 {
   SetRow("FILTER_ONAIR_FLAG",RDYesNo(state));
 }
 
 
+bool RDReport::filterGroups() const
+{
+  return RDBool(RDGetSqlValue("REPORTS","NAME",report_name,"FILTER_GROUPS").
+    toString());
+}
+
+
+void RDReport::setFilterGroups(bool state) const
+{
+  SetRow("FILTER_GROUPS",RDYesNo(state));
+}
+
+
 RDReport::ErrorCode RDReport::errorCode() const
 {
   return report_error_code;
@@ -227,7 +243,7 @@ RDReport::ErrorCode RDReport::errorCode() const
 
 
 bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
-			      RDStation *station)
+			      RDStation *station,QString *out_path)
 {
   QString sql;
   RDSqlQuery *q;
@@ -259,10 +275,12 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   //
   // Next, the group list
   //
+  bool where=false;
   if(exportTypeEnabled(RDReport::Generic)) {
     sql="select NAME from GROUPS  ";
   }
   else {
+    where=true;
     sql="select NAME from GROUPS where ";
     if(exportTypeEnabled(RDReport::Traffic)) {
       sql+="(REPORT_TFC=\"Y\")||";
@@ -271,6 +289,21 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
       sql+="(REPORT_MUS=\"Y\")||";
     }
   }
+  if(filterGroups()) {
+    QString sql2=QString().sprintf("select GROUP_NAME from REPORT_GROUPS \
+                                    where REPORT_NAME=\"%s\"",
+				   (const char *)RDEscapeString(name()));
+    q=new RDSqlQuery(sql2);
+    while(q->next()) {
+      if(!where) {
+	sql+="where ";
+	where=true;
+      }
+      sql+=QString().sprintf("(NAME=\"%s\")||",
+		     (const char *)RDEscapeString(q->value(0).toString()));
+    }
+    delete q;
+  }
   sql=sql.left(sql.length()-2);
   q=new RDSqlQuery(sql);
   while(q->next()) {
@@ -325,8 +358,9 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
                            LOG_NAME,`%s_SRT`.TITLE,`%s_SRT`.ARTIST,\
                            SCHEDULED_TIME,\
                            START_SOURCE,`%s_SRT`.PUBLISHER,`%s_SRT`.COMPOSER,\
+                           `%s_SRT`.ALBUM,`%s_SRT`.LABEL,\
                            `%s_SRT`.ISRC,`%s_SRT`.USAGE_CODE,\
-                           `%s_SRT`.ONAIR_FLAG from `%s_SRT`\
+                           `%s_SRT`.ONAIR_FLAG,`%s_SRT`.ISCI from `%s_SRT`\
                            left join CART on `%s_SRT`.CART_NUMBER=CART.NUMBER \
                            where (EVENT_DATETIME>=\"%s 00:00:00\")&&\
                            (EVENT_DATETIME<=\"%s 23:59:59\")&&(%s)",
@@ -339,6 +373,9 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 			    (const char *)rec_name,
 			    (const char *)rec_name,
 			    (const char *)rec_name,
+			    (const char *)rec_name,
+			    (const char *)rec_name,
+			    (const char *)rec_name,
 			    (const char *)startdate.toString("yyyy-MM-dd"),
 			    (const char *)enddate.toString("yyyy-MM-dd"),
 			    (const char *)station_sql);
@@ -358,13 +395,20 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
       q1=new RDSqlQuery(sql);
       while(q1->next()) {
 	sql=QString().sprintf("insert into `%s_SRT` set\
-                             LENGTH=%d,LOG_ID=%u,CART_NUMBER=%d,\
-                             STATION_NAME=\"%s\",EVENT_DATETIME=\"%s\",\
-                             EVENT_TYPE=%d,EXT_START_TIME=\"%s\",\
-                             EXT_LENGTH=%d,EXT_DATA=\"%s\",\
-                             EXT_EVENT_ID=\"%s\",EXT_ANNC_TYPE=\"%s\",\
+                             LENGTH=%d,\
+                             LOG_ID=%u,\
+                             CART_NUMBER=%d,\
+                             STATION_NAME=\"%s\",\
+                             EVENT_DATETIME=\"%s\",\
+                             EVENT_TYPE=%d,\
+                             EXT_START_TIME=\"%s\",\
+                             EXT_LENGTH=%d,\
+                             EXT_DATA=\"%s\",\
+                             EXT_EVENT_ID=\"%s\",\
+                             EXT_ANNC_TYPE=\"%s\",\
                              PLAY_SOURCE=%d,\
-                             CUT_NUMBER=%d,EVENT_SOURCE=%d,\
+                             CUT_NUMBER=%d,\
+                             EVENT_SOURCE=%d,\
                              EXT_CART_NAME=\"%s\",\
                              LOG_NAME=\"%s\",\
                              TITLE=\"%s\",\
@@ -373,9 +417,12 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
                              START_SOURCE=%d,\
                              PUBLISHER=\"%s\",\
                              COMPOSER=\"%s\",\
+                             ALBUM=\"%s\",\
+                             LABEL=\"%s\",\
                              ISRC=\"%s\",\
                              USAGE_CODE=%d,\
-                             ONAIR_FLAG=\"%s\"",
+                             ONAIR_FLAG=\"%s\",\
+                             ISCI=\"%s\"",
 			      (const char *)mixname,
 			      q1->value(0).toInt(),
 			      q1->value(1).toUInt(),
@@ -414,9 +461,15 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 			      RDEscapeString(q1->value(21).toString()),
 			      (const char *)
 			      RDEscapeString(q1->value(22).toString()),
-			      q1->value(23).toInt(),
 			      (const char *)
-			      RDEscapeString(q1->value(24).toString()));
+			      RDEscapeString(q1->value(23).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(24).toString()),
+			      q1->value(25).toInt(),
+			      (const char *)
+			      RDEscapeString(q1->value(26).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(27).toString()));
 	q2=new RDSqlQuery(sql);
 	delete q2;
       }
@@ -448,15 +501,45 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 	ret=ExportSoundEx(startdate,enddate,mixname);
 	break;
 
+      case RDReport::NprSoundExchange:
+	ret=ExportNprSoundEx(startdate,enddate,mixname);
+	break;
+
       case RDReport::RadioTraffic:
 	ret=ExportRadioTraffic(startdate,enddate,mixname);
 	break;
 
+      case RDReport::VisualTraffic:
+	ret=ExportDeltaflex(startdate,enddate,mixname);
+	break;
+
+      case RDReport::CounterPoint:
+      case RDReport::WideOrbit:
+	ret=ExportRadioTraffic(startdate,enddate,mixname);
+	break;
+
+      case RDReport::Music1:
+	ret=ExportRadioTraffic(startdate,enddate,mixname);
+	break;
+
+      case RDReport::MusicPlayout:
+	ret=ExportMusicPlayout(startdate,enddate,mixname);
+	break;
+
+      case RDReport::MusicSummary:
+	ret=ExportMusicSummary(startdate,enddate,mixname);
+	break;
+
       default:
 	return false;
 	break;
   }
-  // printf("MIXDOWN TABLE: %s_SRT\n",(const char *)mixname);
+#ifdef WIN32
+  *out_path=RDDateDecode(exportPath(RDReport::Windows),startdate);
+#else
+  *out_path=RDDateDecode(exportPath(RDReport::Linux),startdate);
+#endif
+  //printf("MIXDOWN TABLE: %s_SRT\n",(const char *)mixname);
   sql=QString().sprintf("drop table `%s_SRT`",(const char *)mixname);
   q=new RDSqlQuery(sql);
   delete q;
@@ -469,27 +552,48 @@ QString RDReport::filterText(RDReport::ExportFilter filter)
 {
   switch(filter) {
       case RDReport::CbsiDeltaFlex:
-	return QT_TR_NOOP("CBSI DeltaFlex Traffic Reconciliation v2.01");
+	return QObject::tr("CBSI DeltaFlex Traffic Reconciliation v2.01");
 
       case RDReport::TextLog:
-	return QT_TR_NOOP("Text Log");
+	return QObject::tr("Text Log");
 
       case RDReport::BmiEmr:
-	return QT_TR_NOOP("ASCAP/BMI Electronic Music Report");
+	return QObject::tr("ASCAP/BMI Electronic Music Report");
 
       case RDReport::Technical:
-	return QT_TR_NOOP("Technical Playout Report");
+	return QObject::tr("Technical Playout Report");
 
       case RDReport::SoundExchange:
-	return QT_TR_NOOP("SoundExchange Statutory License Report");
+	return QObject::tr("SoundExchange Statutory License Report");
+
+      case RDReport::NprSoundExchange:
+	return QObject::tr("NPR/DS SoundExchange Report");
 
       case RDReport::RadioTraffic:
-	return QT_TR_NOOP("RadioTraffic.com Traffic Reconciliation");
+	return QObject::tr("RadioTraffic.com Traffic Reconciliation");
+
+      case RDReport::VisualTraffic:
+	return QObject::tr("VisualTraffic Reconciliation");
+
+      case RDReport::CounterPoint:
+	return QObject::tr("CounterPoint Traffic Reconciliation");
+
+      case RDReport::Music1:
+	return QObject::tr("Music1 Reconciliation");
+
+      case RDReport::MusicPlayout:
+	return QObject::tr("Music Playout");
+
+      case RDReport::MusicSummary:
+	return QObject::tr("Music Summary");
+
+      case RDReport::WideOrbit:
+	return QObject::tr("WideOrbit Traffic Reconciliation");
 
       default:
-	break;
+	return QObject::tr("Unknown");
   }
-  return QT_TR_NOOP("Unknown");
+  return QObject::tr("Unknown");
 }
 
 
@@ -497,34 +601,41 @@ QString RDReport::stationTypeText(RDReport::StationType type)
 {
   switch(type) {
       case RDReport::TypeOther:
-	return QT_TR_NOOP("Other");
+	return QObject::tr("Other");
 
       case RDReport::TypeAm:
-	return QT_TR_NOOP("AM");
+	return QObject::tr("AM");
 
       case RDReport::TypeFm:
-	return QT_TR_NOOP("FM");
+	return QObject::tr("FM");
 
       default:
 	break;
   }
-  return QT_TR_NOOP("Unknown");
+  return QObject::tr("Unknown");
 }
 
 
 bool RDReport::multipleDaysAllowed(RDReport::ExportFilter filter)
 {
   switch(filter) {
-      case RDReport::CbsiDeltaFlex:
-      case RDReport::TextLog:
-      case RDReport::RadioTraffic:
-      case RDReport::LastFilter:
-	return false;
+  case RDReport::CbsiDeltaFlex:
+  case RDReport::TextLog:
+  case RDReport::RadioTraffic:
+  case RDReport::VisualTraffic:
+  case RDReport::CounterPoint:
+  case RDReport::LastFilter:
+  case RDReport::Music1:
+  case RDReport::MusicPlayout:
+  case RDReport::WideOrbit:
+    return false;
 
-      case RDReport::BmiEmr:
-      case RDReport::SoundExchange:
-      case RDReport::Technical:
-	return true;
+  case RDReport::BmiEmr:
+  case RDReport::SoundExchange:
+  case RDReport::NprSoundExchange:
+  case RDReport::Technical:
+  case RDReport::MusicSummary:
+    return true;
   }
   return true;
 }
@@ -533,16 +644,23 @@ bool RDReport::multipleDaysAllowed(RDReport::ExportFilter filter)
 bool RDReport::multipleMonthsAllowed(RDReport::ExportFilter filter)
 {
   switch(filter) {
-      case RDReport::CbsiDeltaFlex:
-      case RDReport::TextLog:
-      case RDReport::BmiEmr:
-      case RDReport::RadioTraffic:
-      case RDReport::LastFilter:
-	return false;
-
-      case RDReport::SoundExchange:
-      case RDReport::Technical:
-	return true;
+  case RDReport::CbsiDeltaFlex:
+  case RDReport::TextLog:
+  case RDReport::BmiEmr:
+  case RDReport::RadioTraffic:
+  case RDReport::VisualTraffic:
+  case RDReport::CounterPoint:
+  case RDReport::LastFilter:
+  case RDReport::Music1:
+  case RDReport::MusicPlayout:
+  case RDReport::WideOrbit:
+    return false;
+    
+  case RDReport::SoundExchange:
+  case RDReport::NprSoundExchange:
+  case RDReport::Technical:
+  case RDReport::MusicSummary:
+    return true;
   }
   return true;
 }
@@ -553,22 +671,34 @@ QString RDReport::errorText(RDReport::ErrorCode code)
   QString ret;
   switch(code) {
       case RDReport::ErrorOk:
-	ret=QT_TR_NOOP("Report complete!");
+	ret=QObject::tr("Report complete!");
 	break;
 
       case RDReport::ErrorCanceled:
-	ret=QT_TR_NOOP("Report canceled!");
+	ret=QObject::tr("Report canceled!");
 	break;
 
       case RDReport::ErrorCantOpen:
-	ret=QT_TR_NOOP("Unable to open report file!");
+	ret=QObject::tr("Unable to open report file!");
 	break;
   }
   return ret;
 }
 
 
-void RDReport::SetRow(const QString &param,QString value)
+QString RDReport::StringField(const QString &str) const
+{
+  QString ret="[unknown]";
+
+  if(!str.isEmpty()) {
+    ret=str;
+  }
+
+  return ret;
+}
+
+
+void RDReport::SetRow(const QString &param,QString value) const
 {
   RDSqlQuery *q;
   QString sql;
@@ -582,7 +712,7 @@ void RDReport::SetRow(const QString &param,QString value)
 }
 
 
-void RDReport::SetRow(const QString &param,int value)
+void RDReport::SetRow(const QString &param,int value) const
 {
   RDSqlQuery *q;
   QString sql;
@@ -596,7 +726,7 @@ void RDReport::SetRow(const QString &param,int value)
 }
 
 
-void RDReport::SetRow(const QString &param,unsigned value)
+void RDReport::SetRow(const QString &param,unsigned value) const
 {
   RDSqlQuery *q;
   QString sql;
@@ -610,7 +740,7 @@ void RDReport::SetRow(const QString &param,unsigned value)
 }
 
 
-void RDReport::SetRow(const QString &param,bool value)
+void RDReport::SetRow(const QString &param,bool value) const
 {
   RDSqlQuery *q;
   QString sql;
@@ -624,7 +754,7 @@ void RDReport::SetRow(const QString &param,bool value)
 }
 
 
-QString RDReport::OsFieldName(ExportOs os)
+QString RDReport::OsFieldName(ExportOs os) const
 {
   switch(os) {
       case RDReport::Linux:
@@ -637,7 +767,7 @@ QString RDReport::OsFieldName(ExportOs os)
 }
 
 
-QString RDReport::TypeFieldName(ExportType type,bool forced)
+QString RDReport::TypeFieldName(ExportType type,bool forced) const
 {
   if(forced) {
     switch(type) {
