@@ -1,10 +1,10 @@
-// rdsouond_panel.h
+// rdsound_panel.h
 //
 // The sound panel widget for RDAirPlay
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsound_panel.h,v 1.23 2007/07/10 16:02:21 fredg Exp $
+//      $Id: rdsound_panel.h,v 1.32.6.3 2013/03/13 16:10:43 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,8 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#ifndef RDSOUOND_PANEL_H
-#define RDSOUOND_PANEL_H
+#ifndef RDSOUND_PANEL_H
+#define RDSOUND_PANEL_H
 
 #include <vector>
 
@@ -30,21 +30,17 @@
 #include <qlabel.h>
 #include <qsignalmapper.h>
 
-#include <rpushbutton.h>
-#include <rtransportbutton.h>
+#include <rdpushbutton.h>
 
-#include <rdcae.h>
+#include <rdcart_dialog.h>
 #include <rdcart.h>
-#include <rdstation.h>
 #include <rduser.h>
 #include <rdairplay_conf.h>
-#include <rduser.h>
 #include <rdpanel_button.h>
 #include <rdbutton_dialog.h>
 #include <rdbutton_panel.h>
 #include <rdripc.h>
 #include <rdevent_player.h>
-#include <rdairplay_conf.h>
 #include <rdcombobox.h>
 
 
@@ -60,10 +56,12 @@ class RDSoundPanel : public QWidget
 {
  Q_OBJECT
  public:
-  RDSoundPanel(int cols,int rows,int station_panels,int use_panels,bool flash,
+  RDSoundPanel(int cols,int rows,int station_panels,int user_panels,bool flash,
 	       const QString &label_template,bool extended,
 	       RDEventPlayer *player,RDRipc *ripc,RDCae *cae,
-	       RDStation *station,QWidget *parent=0,const char *name=0);
+	       RDStation *station,RDCartDialog *cart_dialog,
+	       QWidget *parent=0,const char *name=0);
+  ~RDSoundPanel();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   int card(int outnum) const;
@@ -79,13 +77,23 @@ class RDSoundPanel : public QWidget
 		 unsigned cartnum);
   void setLogfile(QString filename);
   void play(RDAirPlayConf::PanelType type,int panel,int row,int col,
-	    RDLogLine::StartSource src);
-  bool pause(RDAirPlayConf::PanelType type,int panel,int row,int col);
-  void stop(RDAirPlayConf::PanelType type,int panel,int row,int col);
+	    RDLogLine::StartSource src,int mport=-1,bool pause_when_finished=false);
+  bool pause(RDAirPlayConf::PanelType type,int panel,int row,int col,int mport=-1);
+  void stop(RDAirPlayConf::PanelType type,int panel,int row,int col,
+  int mport=-1,bool pause_when_finished=false,int fade_out=0);
+  void channelStop(int mport);
+  void setText(RDAirPlayConf::PanelType type,int panel,int row,int col,
+	       const QString &str);
+  void setColor(RDAirPlayConf::PanelType type,int panel,int row,int col,
+		const QColor &color);
+  void duckVolume(RDAirPlayConf::PanelType type,int panel,int row,int col,
+		  int level,int fade,int mport=-1);
   RDAirPlayConf::ActionMode actionMode() const;
   void setActionMode(RDAirPlayConf::ActionMode mode);
   bool pauseEnabled() const;
   void setPauseEnabled(bool state);
+  int currentNumber() const;
+  RDAirPlayConf::PanelType currentType() const;
 
  public slots:
   void changeUser();
@@ -94,26 +102,32 @@ class RDSoundPanel : public QWidget
  signals:
   void tick();
   void buttonFlash(bool state);
-  void selectClicked(unsigned cartnum);
+  void selectClicked(unsigned cartnum,int row,int col);
+  void channelStarted(int mport,int card,int port);
+  void channelStopped(int mport,int card,int port);
 
  private slots:
   void panelActivatedData(int n);
   void playmodeActivatedData(int n);
   void resetClickedData();
+  void allClickedData();
   void setupClickedData();
   void buttonMapperData(int id);
   void stateChangedData(int id,RDPlayDeck::State state);
   void hookEndData(int id);
   void timescalingSupportedData(int card,bool state);
   void panelSetupData();
+  void onairFlagChangedData(bool state);
 
  private:
   void PlayButton(RDAirPlayConf::PanelType type,int panel,int row,int col,
-		  RDLogLine::StartSource src,bool hookmode);
-  bool PlayAudio(RDPanelButton *button,RDCart *cart,bool hookmode);
+		RDLogLine::StartSource src,bool hookmode,int mport=-1,
+                  bool pause_when_finished=false);
+  bool PlayAudio(RDPanelButton *button,RDCart *cart,bool hookmode,int mport=-1);
   void PlayMacro(RDPanelButton *button,RDCart *cart);
-  void PauseButton(RDAirPlayConf::PanelType type,int panel,int row,int col);
-  void StopButton(RDAirPlayConf::PanelType type,int panel,int row,int col);
+  void PauseButton(RDAirPlayConf::PanelType type,int panel,int row,int col,int mport=-1);
+  void StopButton(RDAirPlayConf::PanelType type,int panel,int row,int col,
+               int mport=-1,bool pause_when_finished=false,int fade_out=0);
   void StopButton(int id);
   void StopButton(RDPlayDeck *deck);
   void LoadPanels();
@@ -133,13 +147,14 @@ class RDSoundPanel : public QWidget
   void ClearReset();
   QString PanelTag(int index);
   QString PanelOwner(RDAirPlayConf::PanelType type);
-  std::vector<RDButtonPanel> panel_buttons;
+  std::vector<RDButtonPanel *> panel_buttons;
   RDCae *panel_cae;
   RDUser *panel_user;
   RDComboBox *panel_selector_box;
   QComboBox *panel_playmode_box;
-  RPushButton *panel_setup_button;
-  RPushButton *panel_reset_button;
+  RDPushButton *panel_setup_button;
+  RDPushButton *panel_reset_button;
+  RDPushButton *panel_all_button;
   RDAirPlayConf::PanelType panel_type;
   RDButtonDialog *panel_button_dialog;
   QSignalMapper *panel_mapper;
@@ -156,6 +171,8 @@ class RDSoundPanel : public QWidget
   RDStation *panel_station;
   int panel_card[PANEL_MAX_OUTPUTS];
   int panel_port[PANEL_MAX_OUTPUTS];
+  int panel_cue_card;
+  int panel_cue_port;
   QString panel_output_text[PANEL_MAX_OUTPUTS];
   QString panel_start_rml[PANEL_MAX_OUTPUTS];
   QString panel_stop_rml[PANEL_MAX_OUTPUTS];
@@ -173,6 +190,8 @@ class RDSoundPanel : public QWidget
   bool panel_pause_enabled;
   int panel_button_columns;
   int panel_button_rows;
+  RDCartDialog *panel_cart_dialog;
+  bool panel_onair_flag;
 };
 
-#endif
+#endif  // RDSOUND_PANEL_H
