@@ -2,9 +2,9 @@
 //
 // Abstract a Rivendell Workstation.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdstation.cpp,v 1.23.2.1 2008-11-30 00:32:57 fredg Exp $
+//      $Id: rdstation.cpp,v 1.30.4.3 2012/11/28 21:44:06 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -107,6 +107,52 @@ void RDStation::setAddress(QHostAddress addr) const
 }
 
 
+QString RDStation::httpStation() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"HTTP_STATION").
+    toString();
+}
+
+
+void RDStation::setHttpStation(const QString &str)
+{
+  SetRow("HTTP_STATION",str);
+}
+
+
+QString RDStation::caeStation() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"CAE_STATION").
+    toString();
+}
+
+
+void RDStation::setCaeStation(const QString &str)
+{
+  SetRow("CAE_STATION",str);
+}
+
+
+QString RDStation::webServiceUrl() const
+{
+  QString sql;
+  RDSqlQuery *q;
+  QString addr="localhost";
+
+  if(httpStation()=="localhost") {
+    return QString("http://localhost/rd-bin/rdxport.cgi");
+  }
+  sql=QString().sprintf("select IPV4_ADDRESS from STATIONS where NAME=\"%s\"",
+			(const char *)RDEscapeString(httpStation()));
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    addr=q->value(0).toString();
+  }
+  delete q;
+  return QString("http://")+addr+"/rd-bin/rdxport.cgi";
+}
+
+
 int RDStation::timeOffset()
 {
   if (!time_offset_valid){
@@ -228,6 +274,94 @@ void RDStation::setFilterMode(RDStation::FilterMode mode) const
 }
 
 
+bool RDStation::startJack() const
+{
+  return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,"START_JACK").
+		toString());
+}
+
+
+void RDStation::setStartJack(bool state) const
+{
+  SetRow("START_JACK",RDYesNo(state));
+}
+
+
+QString RDStation::jackServerName() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"JACK_SERVER_NAME").
+    toString();
+}
+
+
+void RDStation::setJackServerName(const QString &str) const
+{
+  SetRow("JACK_SERVER_NAME",str);
+}
+
+
+QString RDStation::jackCommandLine() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"JACK_COMMAND_LINE").
+    toString();
+}
+
+
+void RDStation::setJackCommandLine(const QString &str) const
+{
+  SetRow("JACK_COMMAND_LINE",str);
+}
+
+
+int RDStation::cueCard() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"CUE_CARD").toInt();
+}
+
+
+void RDStation::setCueCard(int card)
+{
+  SetRow("CUE_CARD",card);
+}
+
+
+int RDStation::cuePort() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"CUE_PORT").toInt();
+}
+
+
+void RDStation::setCuePort(int port)
+{
+  SetRow("CUE_PORT",port);
+}
+
+
+int RDStation::cartSlotColumns() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"CARTSLOT_COLUMNS").
+    toInt();
+}
+
+
+void RDStation::setCartSlotColumns(int cols)
+{
+  SetRow("CARTSLOT_COLUMNS",cols);
+}
+
+
+int RDStation::cartSlotRows() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"CARTSLOT_ROWS").toInt();
+}
+
+
+void RDStation::setCartSlotRows(int rows)
+{
+  SetRow("CARTSLOT_ROWS",rows);
+}
+
+
 bool RDStation::systemMaint() const
 {
   return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,"SYSTEM_MAINT").
@@ -280,6 +414,10 @@ bool RDStation::haveCapability(Capability cap) const
       case RDStation::HaveMpg321:
 	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_MPG321").toString());
+
+      case RDStation::HaveTwoLame:
+	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+				  "HAVE_TWOLAME").toString());
 	break;
   }
   return false;
@@ -308,6 +446,10 @@ void RDStation::setHaveCapability(Capability cap,bool state) const
       case RDStation::HaveMpg321:
 	SetRow("HAVE_MPG321",state);
 	break;
+
+      case RDStation::HaveTwoLame:
+	SetRow("HAVE_TWOLAME",state);
+	break;
   }
 }
 
