@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: opendb.cpp,v 1.30 2007/11/07 13:26:55 fredg Exp $
+//      $Id: opendb.cpp,v 1.38 2012/01/12 16:24:50 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -40,6 +40,8 @@
 #include <netdb.h>
 #include <arpa/inet.h>
 
+#include <qobject.h>
+
 /**
  * Get the netmask of an interface and return it via an in_addr struct pointer.
  *
@@ -91,13 +93,13 @@ bool check_remote_server(QString host) {
   rc=gethostname(local_hostname, 255);
   // compare hostnames
   if ((0==rc) && (0!=strncasecmp(local_hostname, (const char *)host, 255))) {
-    if (temp_hostent=gethostbyname(local_hostname))
+    if ((temp_hostent=gethostbyname(local_hostname)))
       local_hostent=*temp_hostent;
     else
       return false;
     local_ip=*(struct in_addr *)temp_hostent->h_addr;
 
-    if (temp_hostent=gethostbyname((const char *)host))
+    if ((temp_hostent=gethostbyname((const char *)host)))
       host_hostent=*temp_hostent;
     else
       return false;
@@ -107,14 +109,16 @@ bool check_remote_server(QString host) {
     if ((local_hostent.h_addrtype == AF_INET) &&
         (host_hostent.h_addrtype == AF_INET) &&
         (local_ip.s_addr != host_ip.s_addr)) {
-      // FIXME: ideally do something smarter than just testing eth0 (note use below in format_remote_host() also)
-      // get list of interfaces   if_nameindex()
-      // loop through list of interfaces, get IP, see if it matches local machine
-      // once have good interface, get netmask
+      // FIXME: ideally do something smarter than just testing eth0 (note use
+      // below in format_remote_host() also)
+      //   get list of interfaces   if_nameindex()
+      //   loop through list of interfaces, get IP, see if it matches local IP
+      //   once have good interface, get netmask
       rc=get_netmask("eth0", &local_netmask);
 
       // compare if IPs are on same subnet.  note: use of bitwise sum
-      if ( (local_ip.s_addr & local_netmask.s_addr) == (host_ip.s_addr & local_netmask.s_addr) )
+      if ( (local_ip.s_addr & local_netmask.s_addr) == 
+                (host_ip.s_addr & local_netmask.s_addr) )
         return true;
     } // endif compare IPs
   } // endif compare hostnames
@@ -148,14 +152,21 @@ QString format_remote_host(const char *hostname) {
 bool OpenDb(QString dbname,QString login,QString pwd,QString host,
 	    QString stationname,bool interactive)
 {
+  // 
+  // Yeesh, this whole method really needs a rewrite!
+  // They shoot horses, don't they??
+  //
+
   int db_ver;
   QString admin_name;
   QString admin_pwd;
   QString sql;
-  RDSqlQuery *q;
+  QSqlQuery *q;
   QString msg;
   MySqlLogin *mysql_login;
   QString str;
+  int err=0;
+  QString err_str="";
 
   //
   // Open Database
@@ -169,44 +180,54 @@ bool OpenDb(QString dbname,QString login,QString pwd,QString host,
   db->setPassword(pwd);
   db->setHostName(host);
   if(!db->open()) {
+    /*
     if(!interactive) {
       return false;
     }
+    */
     RDKillDaemons();
-    msg=QT_TR_NOOP("Unable to access the Rivendell Database!\n\
+    if(interactive) {
+      msg=QObject::tr("Unable to access the Rivendell Database!\n\
 Please enter a login for an account with\n\
 administrative rights on the mySQL server,\n\
 and we will try to get this straightened out.");
-    mysql_login=new MySqlLogin(msg,&admin_name,&admin_pwd);
-    if(mysql_login->exec()!=0) {
+      mysql_login=new MySqlLogin(msg,&admin_name,&admin_pwd);
+      if(mysql_login->exec()!=0) {
+	delete mysql_login;
+	db->removeDatabase(dbname);
+	return false;
+      }
       delete mysql_login;
-      db->removeDatabase(dbname);
-      return false;
     }
-    delete mysql_login;
+    else {
+      admin_name=admin_admin_username;
+      admin_pwd=admin_admin_password;
+      if(!admin_admin_hostname.isEmpty()) {
+	db->setHostName(admin_admin_hostname);
+      }
+    }
     db->setUserName(admin_name);
     db->setPassword(admin_pwd);
     if(db->open()) {      // Fixup DB Access Permsissions
-      QMessageBox::warning(NULL,QT_TR_NOOP("Can't Connect"),
-	          QT_TR_NOOP("Wrong access permissions for accessing mySQL!"));
+      PrintError(QObject::tr("Wrong access permissions for accessing mySQL!"),
+		 interactive);
       db->removeDatabase("mysql");
       return false;
     }
     else {
       db->setDatabaseName("mysql");
       if(!db->open()) {   // mySQL is hosed -- scream and die.
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Connect"),
-			     QT_TR_NOOP("Unable to connect to mySQL!"));
+	PrintError(QObject::tr("Unable to connect to mySQL!"),interactive);
 	db->removeDatabase("mysql");
 	return false;
       }
       else {              // Create a new Rivendell Database
 	sql=QString().sprintf("create database %s",(const char *)dbname);
-	q=new RDSqlQuery(sql);
+	q=new QSqlQuery(sql);
 	if(!q->isActive()) {   // Can't create DB.
 	  delete q;
-	  QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create DB"),
-			 QT_TR_NOOP("Unable to create a Rivendell Database!"));
+	  PrintError(QObject::tr("Unable to create a Rivendell Database!"),
+		     interactive);
 	  db->removeDatabase("mysql");
 	  return false;
 	}
@@ -222,7 +243,7 @@ and we will try to get this straightened out.");
 	sql=QString().sprintf("insert into user set Host=\"%s\",\
             User=\"%s\",Password=PASSWORD(\"%s\")",
 			      (const char *)host, (const char *)login,(const char *)pwd);
-	q=new RDSqlQuery(sql);
+	q=new QSqlQuery(sql);
 	delete q;
 	sql=QString().
 	  sprintf("insert into db set Host=\"%s\",Db=\"%s\",\
@@ -230,23 +251,27 @@ and we will try to get this straightened out.");
             Delete_priv=\"Y\",Create_priv=\"Y\",Drop_priv=\"Y\",\
             Index_priv=\"Y\",Alter_priv=\"Y\",Lock_tables_priv=\"Y\"",
 		 (const char *)host, (const char *)dbname,(const char *)login);
-	q=new RDSqlQuery(sql);
+	q=new QSqlQuery(sql);
 	delete q;
-	q=new RDSqlQuery("flush privileges");
+	q=new QSqlQuery("flush privileges");
 	delete q;
 	db->close();   // Relinquish admin perms
+	if(!admin_admin_dbname.isEmpty()) {
+	  dbname=admin_admin_dbname;
+	}
 	db->setDatabaseName(dbname);
 	db->setUserName(login);
 	db->setPassword(pwd);
+	db->setHostName(host);
 	if(!db->open()) {   // Can't open new database
-	  QMessageBox::warning(NULL,QT_TR_NOOP("Can't Connect"),
-		 QT_TR_NOOP("Unable to connect to new Rivendell Database!"));
+	  PrintError(QObject::tr("Unable to connect to new Rivendell Database!"),
+		     interactive);
 	  db->removeDatabase(dbname);
 	  return false;
 	}
 	if(!CreateDb(login,pwd)) {   // Can't create tables.
-	  QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create"),
-			       QT_TR_NOOP("Unable to create Rivendell Database!"));
+	  PrintError(QObject::tr("Unable to create Rivendell Database!"),
+		     interactive);
 	  db->removeDatabase(dbname);
 	  return false;
 	}
@@ -255,19 +280,21 @@ and we will try to get this straightened out.");
 	db->setUserName(login);
 	db->setPassword(pwd);
 	if(!db->open()) {
-	  QMessageBox::warning(NULL,QT_TR_NOOP("Can't Connect"),
-			       QT_TR_NOOP("Unable to connect to Rivendell Database!"));
+	  PrintError(QObject::tr("Unable to connect to Rivendell Database!"),
+		     interactive);
 	  db->removeDatabase(dbname);
 	  return false;
 	}	  
 	if(!InitDb(login,pwd,stationname)) {  // Can't initialize tables.
-	  QMessageBox::warning(NULL,QT_TR_NOOP("Can't Initialize"),
-			       QT_TR_NOOP("Unable to initialize Rivendell Database!"));
+	  PrintError(QObject::tr("Unable to initialize Rivendell Database!"),
+		     interactive);
 	  db->removeDatabase(dbname);
 	  return false;
 	}
-	QMessageBox::information(NULL,QT_TR_NOOP("Created Database"),
-			     QT_TR_NOOP("New Rivendell Database Created!"));
+	if(interactive) {
+	  QMessageBox::information(NULL,QObject::tr("RDAdmin"),
+			      QObject::tr("New Rivendell Database Created!"));
+	}
 	return true;
       }
     }
@@ -276,38 +303,45 @@ and we will try to get this straightened out.");
   if((db_ver=RDCheckVersion())<RD_VERSION_DATABASE) {
     if(db_ver==0) {    // Pre-historic database version!
       if(!interactive) {
+	PrintError(QObject::tr("Unable to upgrade database"),false);
 	return false;
       }
-      msg=QT_TR_NOOP("The Rivendell Database is too old to be upgraded,\n\
+      msg=QObject::tr("The Rivendell Database is too old to be upgraded,\n\
 and so must be replaced.  This will DESTROY any\n\
 existing audio and data!  If you want to do this,\n\
 enter a username and password for a mySQL account\n\
 with administrative privledges, otherwise hit cancel.");
-      mysql_login=new MySqlLogin(msg,&admin_name,&admin_pwd);
-      if(mysql_login->exec()!=0) {
+      if(interactive) {
+	mysql_login=new MySqlLogin(msg,&admin_name,&admin_pwd);
+	if(mysql_login->exec()!=0) {
+	  delete mysql_login;
+	  db->removeDatabase(dbname);
+	  return false;
+	}
 	delete mysql_login;
-	db->removeDatabase(dbname);
-	return false;
       }
-      delete mysql_login;
+      else {
+	admin_name=admin_admin_username;
+	admin_pwd=admin_admin_password;
+      }
       RDKillDaemons();
       db->close();
       db->setDatabaseName("mysql");
       db->setUserName(admin_name);
       db->setPassword(admin_pwd);
       if(!db->open()) {
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Connect"),
-		   QT_TR_NOOP("Unable to log into Administrator account!"));
+	PrintError(QObject::tr("Unable to log into Administrator account!"),
+		   interactive);
 	db->removeDatabase(dbname);
 	return false;
       }	  
-      q=new RDSqlQuery("drop database Rivendell");
+      q=new QSqlQuery(QString().sprintf ("drop database %s",(const char *)dbname));
       delete q;
-      q=new RDSqlQuery("create database Rivendell");
+      q=new QSqlQuery(QString().sprintf("create database %s",(const char *)dbname));
       if(!q->isActive()) {   // Can't create DB.
 	delete q;
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create DB"),
-		  QT_TR_NOOP("Unable to create a Rivendell Database!"));
+	PrintError(QObject::tr("Unable to create a Rivendell Database!"),
+		   interactive);
 	db->removeDatabase("mysql");
 	return false;
       }
@@ -315,10 +349,10 @@ with administrative privledges, otherwise hit cancel.");
       sql=QString().
 	sprintf("grant all on %s to %s identified by \"%s\"",
 		(const char *)dbname,(const char *)login,(const char *)pwd);
-      q=new RDSqlQuery(sql);
+      q=new QSqlQuery(sql);
       if(!q->isActive()) {  // Can't authorize DB.
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create DB"),
-		  QT_TR_NOOP("Unable to authorize a Rivendell Database!"));
+	PrintError(QObject::tr("Unable to authorize a Rivendell Database!"),
+		   interactive);
 	db->removeDatabase("mysql");
 	return false;
       }
@@ -327,14 +361,14 @@ with administrative privledges, otherwise hit cancel.");
       db->setUserName(login);
       db->setPassword(pwd);
       if(!db->open()) {   // Can't open new database
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Connect"),
-		  QT_TR_NOOP("Unable to connect to new Rivendell Database!"));
+	PrintError(QObject::tr("Unable to connect to new Rivendell Database!"),
+		   interactive);
 	db->removeDatabase(dbname);
 	return false;
       }
       if(!CreateDb(login,pwd)) {   // Can't create tables.
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Create"),
-		  QT_TR_NOOP("Unable to create Rivendell Database!"));
+	PrintError(QObject::tr("Unable to create Rivendell Database!"),
+		   interactive);
 	db->removeDatabase(dbname);
 	return false;
       }
@@ -343,22 +377,22 @@ with administrative privledges, otherwise hit cancel.");
       db->setUserName(login);
       db->setPassword(pwd);
       if(!db->open()) {
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Connect"),
-		  QT_TR_NOOP("Unable to connect to Rivendell Database!"));
+	PrintError(QObject::tr("Unable to connect to Rivendell Database!"),
+		   interactive);
 	db->removeDatabase(dbname);
 	return false;
       }	  
       if(!InitDb(login,pwd,stationname)) {   // Can't initialize tables.
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Initialize"),
-		  QT_TR_NOOP("Unable to initialize Rivendell Database!"));
+	PrintError(QObject::tr("Unable to initialize Rivendell Database!"),
+		   interactive);
 	db->removeDatabase(dbname);
 	return false;
       }
     }
     else {             // Out-of-date version
       if(interactive) {
-	if(QMessageBox::warning(NULL,QT_TR_NOOP("Update Needed"),
-		  QT_TR_NOOP("The Rivendell Database needs to be updated.\n\
+	if(QMessageBox::warning(NULL,QObject::tr("Update Needed"),
+		  QObject::tr("The Rivendell Database needs to be updated.\n\
 All audio and settings will be preserved, but\n\
 this will STOP any audio playout or recording\n\
 on this machine for a few seconds.  Continue?"),
@@ -369,21 +403,36 @@ on this machine for a few seconds.  Continue?"),
 	}      
       }
       RDKillDaemons();
-      if(!UpdateDb(db_ver)) {
-	if(!interactive) {
-	  return false;
+      if((err=UpdateDb(db_ver))!=UPDATEDB_SUCCESS) {
+	err_str=QObject::tr("Unable to update Rivendell Database:");
+	switch(err) {
+	case UPDATEDB_BACKUP_FAILED:
+	  err_str+=QObject::tr("\nDatabase backup failed!");
+	  break;
+
+	case UPDATEDB_QUERY_FAILED:
+	  err_str+=QObject::tr("\nSchema modification failed!");
+	  break;
+
+	default:
+	  err_str+=QObject::tr("\nUnknown/unspecified error!");
+	  break;
 	}
-	QMessageBox::warning(NULL,QT_TR_NOOP("Can't Update"),
-		   QT_TR_NOOP("Unable to update Rivendell Database!"));
+	PrintError(err_str,interactive);
 	db->removeDatabase(dbname);
 	return false;
       }
+      str=QString(
+        QObject::tr("The Rivendell Database has been updated to version"));
+      msg=QString().
+	sprintf("%s %d",(const char *)str,RD_VERSION_DATABASE);
+      if(!admin_skip_backup) {
+	msg+=QObject::tr("\nand a backup of the original database saved in ");
+	msg+=admin_backup_filename;
+      }
+      msg+=".";
       if(interactive) {
-	str=QString(
-	  QT_TR_NOOP("The Rivendell Database has\nbeen updated to Version"));
-	msg=QString().
-	  sprintf("%s %d",(const char *)str,RD_VERSION_DATABASE);
-	QMessageBox::information(NULL,QT_TR_NOOP("Database Updated"),msg);
+	QMessageBox::information(NULL,QObject::tr("Database Updated"),msg);
       }
     }
   }
