@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdadmin.cpp,v 1.64.2.3 2010/01/21 16:44:32 cvs Exp $
+//      $Id: rdadmin.cpp,v 1.72.4.2 2013/01/07 15:34:58 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -54,6 +54,7 @@
 #include <list_reports.h>
 #include <list_feeds.h>
 #include <list_schedcodes.h>
+#include <list_replicators.h>
 #include <edit_settings.h>
 #include <rdadmin.h>
 #include <opendb.h>
@@ -74,9 +75,15 @@ RDRipc *rdripc;
 RDConfig *admin_config;
 RDUser *admin_user;
 RDStation *admin_station;
+RDSystem *admin_system;
 RDCartDialog *admin_cart_dialog;
 bool exiting=false;
-
+QString admin_admin_username;
+QString admin_admin_password;
+QString admin_admin_hostname;
+QString admin_admin_dbname;
+bool admin_skip_backup=false;
+QString admin_backup_filename="";
 
 void SigHandler(int signo)
 {
@@ -94,23 +101,22 @@ void SigHandler(int signo)
 }
 
 
+void PrintError(const QString &str,bool interactive)
+{
+  if(interactive) {
+    QMessageBox::warning(NULL,QObject::tr("RDAdmin Error"),str);
+  }
+  else {
+    fprintf(stderr,QString().sprintf("rdadmin: %s\n",(const char *)str));
+  }
+}
+
+
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QWidget(parent,name)
 {
   QString str;
 
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-
-  //
-  // Read Command Options
-  //
-  RDCmdSwitch *cmd=
-    new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdadmin",RDADMIN_USAGE);
-  delete cmd;
-
   //
   // Fix the Window Size
   //
@@ -140,7 +146,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   admin_config=new RDConfig();
   admin_config->load();
 
-  str=QString(tr("RDAdmin - Host:"));
+  str=QString(tr("RDAdmin")+" v"+VERSION+" - Host:");
   setCaption(QString().
 	     sprintf("%s %s",(const char *)str,
 		     (const char *)admin_config->stationName()));
@@ -173,6 +179,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   rdripc=new RDRipc(admin_config->stationName(),this,"rdripc");
   rdripc->connectHost("localhost",RIPCD_TCP_PORT,temp);
   admin_station=new RDStation(admin_config->stationName(),this);
+  admin_system=new RDSystem();
 
   //
   // Log In
@@ -197,8 +204,9 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Cart Dialog
   //
-  admin_cart_dialog=new RDCartDialog(&admin_filter,&admin_group,-1,-1,0,0,NULL,
-				     rdripc,admin_station,"",
+  admin_cart_dialog=new RDCartDialog(&admin_filter,&admin_group,
+				     &admin_schedcode,-1,-1,0,0,NULL,
+				     rdripc,admin_station,admin_system,"",
 				     this,"admin_cart_dialog");
 
   //
@@ -288,11 +296,20 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   schedcodes_button->setText(tr("Scheduler\nCodes"));
   connect(schedcodes_button,SIGNAL(clicked()),this,SLOT(manageSchedCodes()));
 
+  //
+  // Manage Replicators Button
+  //
+  QPushButton *repl_button=new QPushButton(this,"repl_button");
+  repl_button->setGeometry(10,190,80,60);
+  repl_button->setFont(font);
+  repl_button->setText(tr("Manage\nReplicators"));
+  connect(repl_button,SIGNAL(clicked()),this,SLOT(manageReplicatorsData()));
+
   //
   // System Info Button
   //
   QPushButton *info_button=new QPushButton(this,"info_button");
-  info_button->setGeometry(55,190,80,60);
+  info_button->setGeometry(100,190,80,60);
   info_button->setFont(font);
   info_button->setText(tr("System\nInfo"));
   connect(info_button,SIGNAL(clicked()),this,SLOT(systemInfoData()));
@@ -301,7 +318,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Backup Database Button
   //
   QPushButton *backup_button=new QPushButton(this,"backup_button");
-  backup_button->setGeometry(145,190,80,60);
+  backup_button->setGeometry(190,190,80,60);
   backup_button->setFont(font);
   backup_button->setText(tr("&Backup\nDatabase"));
   connect(backup_button,SIGNAL(clicked()),this,SLOT(backupData()));
@@ -310,7 +327,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Restore Database Button
   //
   QPushButton *restore_button=new QPushButton(this,"restore_button");
-  restore_button->setGeometry(235,190,80,60);
+  restore_button->setGeometry(280,190,80,60);
   restore_button->setFont(font);
   restore_button->setText(tr("&Restore\nDatabase"));
   connect(restore_button,SIGNAL(clicked()),this,SLOT(restoreData()));
@@ -464,6 +481,7 @@ void MainWidget::restoreData()
     ver=q->value(0).toInt();
   }
   delete q;
+  admin_skip_backup=true;
   UpdateDb(ver);
   QMessageBox::information(this,tr("Restore Complete"),
 			   tr("Restore completed successfully."));
@@ -471,6 +489,14 @@ void MainWidget::restoreData()
 }
 
 
+void MainWidget::manageReplicatorsData()
+{
+  ListReplicators *d=new ListReplicators(this);
+  d->exec();
+  delete d;
+}
+
+
 void MainWidget::systemInfoData()
 {
   InfoDialog *info=new InfoDialog(this,"info_dialog");
@@ -586,9 +612,35 @@ int main(int argc,char *argv[])
   int ret;
   bool found_check_db=false;
 
-  for(int i=0;i<argc;i++) {
-    if(!strcmp(argv[i],"--check-db")) {
+  RDCmdSwitch *cmd=new RDCmdSwitch(argc,argv,"rdadmin",RDADMIN_USAGE);
+  for(unsigned i=0;i<cmd->keys();i++) {
+    if(cmd->key(i)=="--check-db") {
       found_check_db=true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--mysql-admin-user") {
+      admin_admin_username=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--mysql-admin-password") {
+      admin_admin_password=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--mysql-admin-hostname") {
+      admin_admin_hostname=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--mysql-admin-dbname") {
+      admin_admin_dbname=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--backup-filename") {
+      admin_backup_filename=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--skip-backup") {
+      admin_skip_backup=true;
+      cmd->setProcessed(i,true);
     }
   }
   if(found_check_db) {
