@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: wall_clock.cpp,v 1.15 2007/10/01 10:40:45 fredg Exp $
+//      $Id: wall_clock.cpp,v 1.21 2011/01/11 12:20:31 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,7 +21,7 @@
 //
 
 #include <qpainter.h>
-#include <qbitmap.h>
+#include <qpixmap.h>
 #include <qdatetime.h>
 #include <qfontmetrics.h>
 #include <qsize.h>
@@ -36,15 +36,16 @@
 #include <globals.h>
 
 WallClock::WallClock(QWidget *parent,const char *name)
-  :RDPushButton(parent,name)
+  :QPushButton(parent,name)
 {
   time_offset=rdstation_conf->timeOffset();
   previous_time=QTime::currentTime().addMSecs(time_offset);
   time_mode=RDAirPlayConf::TwentyFourHour;
   previous_time_mode = RDAirPlayConf::TwentyFourHour;
   show_date=true;
-  setFlashColor(QColor(BUTTON_TIME_SYNC_LOST_COLOR));
+  //  setFlashColor(QColor(BUTTON_TIME_SYNC_LOST_COLOR));
   check_sync=true;
+  flash_state=false;
 
   //
   // Generate Fonts
@@ -108,13 +109,13 @@ void WallClock::tickClock()
 {
   static QString date;
   QString accum;
-  static QBitmap *pix=new QBitmap(sizeHint().width(),sizeHint().height());
+  static QPixmap *pix=new QPixmap(sizeHint().width(),sizeHint().height());
   static bool synced=true;
 
   if(check_sync) {
     if(RDTimeSynced()!=synced) {
       synced=RDTimeSynced();
-      setFlashingEnabled(!synced);
+      //setFlashingEnabled(!synced);
     }
   }
   current_time=QTime::currentTime().addMSecs(time_offset);
@@ -134,12 +135,28 @@ void WallClock::tickClock()
   else {
     accum=current_time.toString("hh:mm:ss");
   }
+  if(time_string==accum) {
+    return;
+  }
+  time_string=accum;
+  if(synced) {
+    flash_state=false;
+  }
+  else {
+    flash_state=!flash_state;
+  }
   if(previous_date!=current_date) {
     previous_date=current_date;
     date=current_date.toString("dddd, MMMM d, yyyy");
   }
   QPainter p(pix);
-  p.eraseRect(0,0,width(),height());
+  if(flash_state) {
+    p.fillRect(0,0,width(),height(),BUTTON_TIME_SYNC_LOST_COLOR);
+  }
+  else {
+    p.fillRect(0,0,width(),height(),backgroundColor());
+  }
+  //p.eraseRect(0,0,width(),height());
   p.setPen(color1);
   p.setBrush(color1);
   p.setFont(label_font);
@@ -151,6 +168,15 @@ void WallClock::tickClock()
 }
 
 
+void WallClock::flashButton(bool state)
+{
+  printf("flashButton()\n");
+  flash_state=state;
+  tickClock();
+  //  RDPushButton::flashButton(state);
+}
+
+
 void WallClock::keyPressEvent(QKeyEvent *e)
 {
   e->ignore();
