@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: globals.h,v 1.7 2007/12/31 18:49:10 fredg Exp $
+//      $Id: globals.h,v 1.8 2010/07/29 19:32:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,6 +31,7 @@
 #include <rdcae.h>
 #include <rdripc.h>
 #include <rdcart_dialog.h>
+#include <rdsystem.h>
 
 //
 // Global Resources
@@ -45,5 +46,6 @@ extern RDCae *catch_cae;
 extern RDCartDialog *catch_cart_dialog;
 extern int catch_audition_card;
 extern int catch_audition_port;
+extern RDSystem *catch_system;
 
 #endif  // GLOBALS_H
