@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003, 2009 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cdripper.cpp,v 1.36.2.3 2009/08/04 20:56:49 cvs Exp $
+//      $Id: cdripper.cpp,v 1.41 2011/12/23 22:04:11 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -37,6 +37,8 @@
 #include <rdconf.h>
 #include <rdwavefile.h>
 #include <rdcut.h>
+#include <rdcdripper.h>
+#include <rdaudioimport.h>
 
 #include <cdripper.h>
 #include <globals.h>
@@ -68,14 +70,17 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   QFont label_font=QFont("Helvetica",12,QFont::Bold);
   label_font.setPixelSize(12);
 
-  rip_cutname=cutname;
-  rip_wavefile=RDCut::pathName(cutname); 
   rip_conf=conf;
   rip_cddb_record=rec;
   rip_track=-1;
 
   setCaption("Rip CD");
 
+  //
+  // Target Cut
+  //
+  rip_cut=new RDCut(cutname);
+
   //
   // The CDROM Drive
   //
@@ -173,12 +178,6 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_bar=new QProgressBar(this,"rip_bar");
   rip_bar->setGeometry(10,480,sizeHint().width()-110,20);
 
-  //
-  // Progress Bar Timer
-  //
-  rip_bar_timer=new QTimer(this,"rip_bar_timer");
-  connect(rip_bar_timer,SIGNAL(timeout()),this,SLOT(barTimerData()));
-
   //
   // Eject Button
   //
@@ -316,7 +315,6 @@ CdRipper::~CdRipper()
   delete rip_play_button;
   delete rip_stop_button;
   delete rip_bar;
-  delete rip_bar_timer;
 }
 
 
@@ -364,127 +362,125 @@ void CdRipper::stopButtonData()
 
 void CdRipper::ripTrackButtonData()
 {
-  QString cmd;
-  bool rc;
-  mode_t prev_mask;
-
-  if(!ripper_running) {
-    rip_done=false;
-    rip_rip_aborted=false;
-    bar_file=new QFile(rip_wavefile);
-    if(bar_file->exists()) {
-      switch(QMessageBox::warning(this,tr("Audio Exists"),
-				  tr("This will overwrite the existing recording.\nDo you want to proceed?"),
-				  QMessageBox::Yes,QMessageBox::No)) {
-	  case QMessageBox::No:
-	  case QMessageBox::NoButton:
-	    delete bar_file;
-	    return;
-
-	  default:
-	    break;
-      }
-    }
-    if(cut_clipboard!=NULL) {
-      if(rip_cutname==cut_clipboard->cutName()) {
-	switch(QMessageBox::warning(this,tr("Empty Clipboard"),
-				    tr("Ripping this cut will also empty the clipboard.\nDo you still want to proceed?"),
-				    QMessageBox::Yes,
-				    QMessageBox::No)) {
-	    case QMessageBox::No:
-	    case QMessageBox::NoButton:
-	      return;
-
-	    default:
-	      break;
-	}
-	delete cut_clipboard;
-	cut_clipboard=NULL;
-      }
-    }
-    prev_mask = umask(0113);      // Set umask so files are user and group writable.
-    rc=bar_file->open(IO_WriteOnly);
-    umask(prev_mask);
-    if(!rc) {
-      QMessageBox::warning(this,tr("No Access"),
-			   tr("Unable to open the file for writing!"),
-			   tr("OK"));
-      delete bar_file;
+  rip_done=false;
+  rip_rip_aborted=false;
+  if(rip_cut->length()>0) {
+    switch(QMessageBox::warning(this,tr("Audio Exists"),
+				tr("This will overwrite the existing recording.\nDo you want to proceed?"),
+				QMessageBox::Yes,QMessageBox::No)) {
+    case QMessageBox::No:
+    case QMessageBox::NoButton:
       return;
+      
+    default:
+      break;
     }
-    bar_file->close();
-    rip_eject_button->setDisabled(true);
-    rip_play_button->setDisabled(true);
-    rip_stop_button->setDisabled(true);
-    rip_rip_button->setDisabled(true);
-    rip_close_button->setDisabled(true);
-    rip_temp_length=(int)((double)rip_cdrom->
-	    trackLength(rip_track_list->currentItem()->text(0).toInt())*176.4);
-    switch(rip_conf->defaultFormat()) {
-	case 0:  // PCM16
-	  rip_finished_length=
-	    (int)(((double)rip_temp_length/2.0)*
-		  (double)(rip_channels_box->currentItem()+1.0)*
-		  (double)rip_conf->defaultSampleRate()/44100.0);
-	  break;
-	case 1:  // MPEG-1 Layer 2
-	case 2:  // MPEG-1 Layer 3
-	  rip_finished_length=
-	    (int)((double)rip_temp_length*
-		  (double)(rip_channels_box->currentItem()+1)*
-		  (double)rip_conf->defaultBitrate()/1411200.0);
-	  break;
+  }
+  if(cut_clipboard!=NULL) {
+    if(rip_cut->cutName()==cut_clipboard->cutName()) {
+      switch(QMessageBox::warning(this,tr("Empty Clipboard"),
+				  tr("Ripping this cut will also empty the clipboard.\nDo you still want to proceed?"),
+				  QMessageBox::Yes,
+				  QMessageBox::No)) {
+      case QMessageBox::No:
+      case QMessageBox::NoButton:
+	return;
+
+      default:
+	break;
+      }
+      delete cut_clipboard;
+      cut_clipboard=NULL;
     }
-    rip_track=rip_track_list->currentItem()->text(0).toInt()-1;
-    if(rip_normalize_box->isChecked()) {
-     cmd=QString().sprintf("rd_rip_cd %d %s %d %6.4lf %d %d %d %d %s %s/%s %s/%s",
-	  rip_track_list->currentItem()->text(0).toInt(),
-	  (const char *)rip_conf->ripperDevice(),
-	  rip_conf->paranoiaLevel(),
-	  pow(10.0,(double)(rip_normalize_spin->value())/20.0),
-	  rip_conf->defaultFormat(),
-	  rip_channels_box->currentItem()+1,
-	  rip_conf->defaultSampleRate(),
-	  (rip_channels_box->currentItem()+1)*rip_conf->defaultBitrate()/1000, 
-	  (const char *)rip_wavefile,
-	  RIPPER_TEMP_DIR,
-	  RIPPER_TEMP_PEAK,
-	  RIPPER_TEMP_DIR,
-	  RIPPER_TEMP_WAV);
+  }
+  rip_eject_button->setDisabled(true);
+  rip_play_button->setDisabled(true);
+  rip_stop_button->setDisabled(true);
+  rip_rip_button->setText(tr("Abort\nRip"));
+  rip_close_button->setDisabled(true);
+
+  //
+  // Rip from disc
+  //
+  RDAudioImport::ErrorCode conv_err;
+  RDAudioConvert::ErrorCode audio_conv_err;
+  RDCdRipper::ErrorCode ripper_err;
+  QString tmpdir=RDTempDir();
+  QString tmpfile=tmpdir+"/"+RIPPER_TEMP_WAV;
+  RDCdRipper *ripper=new RDCdRipper(this);
+  disconnect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripTrackButtonData()));
+  connect(rip_rip_button,SIGNAL(clicked()),ripper,SLOT(abort()));
+  rip_bar->setTotalSteps(ripper->totalSteps()+1);
+  connect(ripper,SIGNAL(progressChanged(int)),rip_bar,SLOT(setProgress(int)));
+  RDAudioImport *conv=NULL;
+  RDSettings *settings=NULL;
+  ripper->setDevice(rip_conf->ripperDevice());
+  ripper->setDestinationFile(tmpfile);
+  rip_track=rip_track_list->currentItem()->text(0).toInt()-1;
+  switch((ripper_err=ripper->rip(rip_track))) {
+  case RDCdRipper::ErrorOk:
+    conv=new RDAudioImport(rdstation_conf,this);
+    conv->setSourceFile(tmpfile);
+    conv->setCartNumber(rip_cut->cartNumber());
+    conv->setCutNumber(rip_cut->cutNumber());
+    conv->setUseMetadata(false);
+    settings=new RDSettings();
+    if(rdlibrary_conf->defaultFormat()==1) {
+      settings->setFormat(RDSettings::MpegL2Wav);
     }
     else {
-     cmd=QString().sprintf("rd_rip_cd %d %s %d 0 %d %d %d %d %s %s/%s %s/%s",
-	  rip_track_list->currentItem()->text(0).toInt(),
-	  (const char *)rip_conf->ripperDevice(),
-	  rip_conf->paranoiaLevel(),
-	  rip_conf->defaultFormat(),
-	  rip_channels_box->currentItem()+1,
-	  rip_conf->defaultSampleRate(),
-	  (rip_channels_box->currentItem()+1)*rip_conf->defaultBitrate()/1000,
-	  (const char *)rip_wavefile,
-	  RIPPER_TEMP_DIR,
-	  RIPPER_TEMP_PEAK,
-	  RIPPER_TEMP_DIR,
-	  RIPPER_TEMP_WAV);
+      settings->setFormat(RDSettings::Pcm16);
     }
-    ripper_running=true;
-    bar_temp_file=new QFile(QString(RIPPER_TEMP_DIR)+QString("/")+
-			    QString(RIPPER_TEMP_WAV));
-    if((rip_ripper_pid=fork())==0) {
-      if(system(cmd)!=0) {
-	bar_file->remove();
-      }
-      exit(0);
+    settings->setChannels(rip_channels_box->currentText().toInt());
+    settings->setSampleRate(lib_system->sampleRate());
+    settings->setBitRate(rdlibrary_conf->defaultBitrate());
+    if(rip_normalize_box->isChecked()) {
+      settings->setNormalizationLevel(rip_normalize_spin->value());
     }
-    rip_bar->setProgress(0);
-    rip_bar->setPercentageVisible(true);
-    rip_bar_timer->start(RIPPER_BAR_INTERVAL,true);
-  }
-  else {
-    rip_rip_aborted=true;
-    bar_file->remove();
-    ::kill(rip_ripper_pid,SIGHUP);
+    if(rip_autotrim_box->isChecked()) {
+      settings->setAutotrimLevel(rip_autotrim_spin->value());
+    }
+    conv->setDestinationSettings(settings);
+    switch((conv_err=conv->
+	  runImport(lib_user->name(),lib_user->password(),&audio_conv_err))) {
+    case RDAudioImport::ErrorOk:
+      QMessageBox::information(this,tr("Rip Complete"),tr("Rip complete!"));
+      break;
+
+    default:
+      QMessageBox::warning(this,tr("RDLibrary - Importer Error"),
+			   RDAudioImport::errorText(conv_err,audio_conv_err));
+      break;
+    }
+    delete settings;
+    delete conv;
+    break;
+
+  case RDCdRipper::ErrorNoDevice:
+  case RDCdRipper::ErrorNoDestination:
+  case RDCdRipper::ErrorInternal:
+  case RDCdRipper::ErrorNoDisc:
+  case RDCdRipper::ErrorNoTrack:
+  case RDCdRipper::ErrorAborted:
+    QMessageBox::warning(this,tr("RDLibrary - Ripper Error"),
+			 RDCdRipper::errorText(ripper_err));
+    break;
   }
+  delete ripper;
+  unlink(tmpfile);
+  rmdir(tmpdir);
+  rip_bar->setPercentageVisible(false);
+  rip_bar->reset();
+  rip_eject_button->setEnabled(true);
+  rip_play_button->setEnabled(true);
+  rip_stop_button->setEnabled(true);
+  rip_rip_button->setText(tr("Rip Track"));
+  connect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripTrackButtonData()));
+  rip_close_button->setEnabled(true);
+  rip_cdrom->unlock();
+  rip_done=true;
+  rip_bar->setProgress(0);
+  rip_bar->setPercentageVisible(true);
 }
 
 
@@ -571,7 +567,6 @@ void CdRipper::cddbDoneData(RDCddbLookup::Result result)
 	break;
       default:
 	rip_track=-1;
-	printf("No Match!\n");
 	break;
   }
 }
@@ -593,58 +588,8 @@ void CdRipper::autotrimCheckData(bool state)
 }
 
 
-void CdRipper::barTimerData()
-{
-  if(ripper_running) {
-    rip_bar->setProgress((int)(50.0*((double)bar_temp_file->
-				     size()/(double)rip_temp_length+
-				     (double)bar_file->size()/
-				     (double)rip_finished_length)));
-    rip_bar_timer->start(RIPPER_BAR_INTERVAL,true);
-  }
-  else {
-    rip_bar->setPercentageVisible(false);
-    rip_bar->reset();
-    rip_eject_button->setEnabled(true);
-    rip_play_button->setEnabled(true);
-    rip_stop_button->setEnabled(true);
-    rip_rip_button->setEnabled(true);
-    rip_close_button->setEnabled(true);
-    rip_cdrom->unlock();
-    if(bar_file->exists()) {
-      rip_done=true;
-      QMessageBox::information(this,tr("Rip Complete"),
-			       tr("Rip complete!"));
-    }
-    else {
-      if(rip_rip_aborted) {
-	QMessageBox::information(this,tr("Rip Aborted"),
-				 tr("The rip has been aborted."));
-
-      }
-      else {
-	QMessageBox::warning(this,tr("Rip Failed"),
-			     tr("The ripper encountered an error.\n\
-Please check your ripper configuration and try again."));
-      }
-    }
-    delete bar_file;
-    delete bar_temp_file;
-    bar_file=NULL;
-    bar_temp_file=NULL;
-    RDCut *cut=new RDCut(rip_cutname);
-    cut->reset();
-    cut->setOriginName(rdstation_conf->name());
-    delete cut;
-  }
-}
-
-
 void CdRipper::closeData()
 {
-  if(rip_done&&rip_autotrim_box->isChecked()) {
-    AutoTrim();
-  }
   if(rip_done&&rip_apply_box->isChecked()) {
     done(rip_track);
   }
@@ -660,35 +605,3 @@ void CdRipper::closeEvent(QCloseEvent *e)
     closeData();
   }
 }
-
-
-void CdRipper::AutoTrim()
-{
-  int point;
-
-  RDCut *cut=new RDCut(rip_cutname);
-  if(!cut->exists()) {
-    delete cut;
-    return;
-  }
-  RDWaveFile *wave=new RDWaveFile(rip_wavefile);
-  if(!wave->openWave()) {
-    delete wave;
-    delete cut;
-    return;
-  }
-  if((point=wave->
-      startTrim(-rip_autotrim_spin->value()*100+REFERENCE_LEVEL))>-1) {
-    cut->setStartPoint((int)(1000.0*(double)point/
-			     (double)wave->getSamplesPerSec()));
-  }
-  if((point=wave->
-      endTrim(-rip_autotrim_spin->value()*100+REFERENCE_LEVEL))>-1) {
-    cut->setEndPoint((int)(1000.0*(double)point/
-			     (double)wave->getSamplesPerSec()));
-  }
-  cut->setLength(cut->endPoint()-cut->startPoint());
-  delete wave;
-  delete cut;
-}
-
