@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cdripper.h,v 1.11 2007/09/14 14:06:55 fredg Exp $
+//      $Id: cdripper.h,v 1.14 2010/07/29 19:32:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -37,6 +37,7 @@
 #include <qcheckbox.h>
 #include <qtextedit.h>
 
+#include <rdcut.h>
 #include <rdtransportbutton.h>
 #include <rdcdplayer.h>
 #include <rdcddbrecord.h>
@@ -60,6 +61,7 @@ class CdRipper : public QDialog
    QSizePolicy sizePolicy() const;
 
   private slots:
+   void trackSelectionChangedData();
    void ejectButtonData();
    void playButtonData();
    void stopButtonData();
@@ -71,18 +73,17 @@ class CdRipper : public QDialog
    void cddbDoneData(RDCddbLookup::Result);
    void normalizeCheckData(bool);
    void autotrimCheckData(bool);
-   void barTimerData();
    void closeData();
 
  protected:
    void closeEvent(QCloseEvent *e);
 
   private:
-   void AutoTrim();
    RDLibraryConf *rip_conf;
    RDCdPlayer *rip_cdrom;
    RDCddbRecord *rip_cddb_record;
    RDCddbLookup *rip_cddb_lookup;
+   RDCut *rip_cut;
    QListView *rip_track_list;
    QPushButton *rip_rip_button;
    bool rip_rip_aborted;
@@ -95,21 +96,12 @@ class CdRipper : public QDialog
    RDTransportButton *rip_eject_button;
    RDTransportButton *rip_play_button;
    RDTransportButton *rip_stop_button;
-   QString rip_cutname;
-   QString rip_wavefile;
    QProgressBar *rip_bar;
    QCheckBox *rip_normalize_box;
    QSpinBox *rip_normalize_spin;
    QLabel *rip_normalize_label;
    QLabel *rip_normalize_unit;
    QComboBox *rip_channels_box;
-   QTimer *rip_bar_timer;
-   QFile *bar_file;
-   QFile *bar_temp_file;
-   int rip_temp_length;
-   int rip_finished_length;
-   pid_t rip_ripper_pid;
-   bool rip_multipass;
    int rip_track;
    QCheckBox *rip_autotrim_box;
    QSpinBox *rip_autotrim_spin;
