@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_cart.cpp,v 1.69.2.3 2009/12/10 23:13:52 cvs Exp $
+//      $Id: edit_cart.cpp,v 1.74 2012/02/13 20:54:27 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,6 +41,8 @@
 #include <rdaudio_exists.h>
 #include <rdsystem.h>
 #include <rdescape_string.h>
+#include <rdaudioexport.h>
+#include <rdupload.h>
 
 #include <cdripper.h>
 #include <edit_cart.h>
@@ -53,33 +55,35 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   : QDialog(parent,name,true)
 {
   bool modification_allowed;
+  rdcart_cart=NULL;
 
   rdcart_new_cart=new_cart;
   sched_codes="";
   add_codes="";
   remove_codes="";
   lib_cart_list_edit=lib_cart_list;
+
   //
   // Fix the Window Size
   //
   setMinimumWidth(sizeHint().width());
   setMaximumWidth(sizeHint().width());
   if(lib_cart_list_edit==NULL) {
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-    }
+    setMinimumHeight(sizeHint().height());
+    setMaximumHeight(sizeHint().height());
+  }
   else {
     setMinimumHeight(sizeHint().height()-270);
     setMaximumHeight(sizeHint().height()-270);
-    }
+  }
 
   if(lib_cart_list_edit==NULL) {
-  rdcart_cart=new RDCart(number);
-  rdcart_import_path=path;
-  setCaption(QString().sprintf("%06u",rdcart_cart->number())+" - "+
-    rdcart_cart->title());
+    rdcart_cart=new RDCart(number);
+    rdcart_import_path=path;
+    setCaption(QString().sprintf("%06u",rdcart_cart->number())+" - "+
+	       rdcart_cart->title());
     modification_allowed=
-    lib_user->modifyCarts()&&rdcart_cart->owner().isEmpty();
+      lib_user->modifyCarts()&&rdcart_cart->owner().isEmpty();
   }
   else {
     setCaption("Edit Carts");
@@ -87,11 +91,10 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   }
 
   //
-  // Create Default Cut
+  // Create Default Audio Cut
   //
-  if(new_cart&&(rdcart_cart->type()==RDCart::Audio)) {
+  if(new_cart&&((rdcart_cart->type()==RDCart::Audio))) {
     rdcart_cart->addCut(rdlibrary_conf->defaultFormat(),
-			rdlibrary_conf->defaultSampleRate(),
 			rdlibrary_conf->defaultBitrate(),
 			rdlibrary_conf->defaultChannels());
   }
@@ -206,8 +209,12 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   //
   // Cart Forced Length
   //
-  rdcart_controls.forced_length_edit=new QTimeEdit(this,"rdcart_forced_length_edit");
-  rdcart_controls.forced_length_edit->setGeometry(535,36,80,21);
+  rdcart_controls.forced_length_edit=
+    new RDTimeEdit(this,"rdcart_forced_length_edit");
+  rdcart_controls.forced_length_edit->setGeometry(530,36,85,21);
+  rdcart_controls.forced_length_edit->
+    setDisplay(RDTimeEdit::Hours|RDTimeEdit::Minutes|RDTimeEdit::Seconds|
+	       RDTimeEdit::Tenths);
   rdcart_controls.forced_length_edit->setFont(line_edit_font);
   rdcart_forced_length_ledit=new QLineEdit(this,"rdcart_forced_length_edit");
   rdcart_forced_length_ledit->setGeometry(535,36,80,21);
@@ -217,7 +224,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_forced_length_label=new QLabel(rdcart_controls.forced_length_edit,
 					tr("Forced Length:"),this,
 					"rdcart_forced_length_label");
-  rdcart_forced_length_label->setGeometry(420,38,110,19);
+  rdcart_forced_length_label->setGeometry(415,38,110,19);
   rdcart_forced_length_label->setFont(button_font);
   rdcart_forced_length_label->setAlignment(AlignRight|ShowPrefix);
   if(lib_cart_list_edit!=NULL) {
@@ -437,23 +444,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   rdcart_user_defined_label->setFont(button_font);
   rdcart_user_defined_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
  
-  //
-  // Cut Scheduling Policy
-  //
-  rdcart_cut_sched_box=new QComboBox(this,"rdcart_cut_sched_box");
-  rdcart_cut_sched_box->setGeometry(135,306,140,21);
-  rdcart_cut_sched_box->setFont(line_edit_font);
-  rdcart_cut_sched_edit=new QLineEdit(this,"rdcart_cut_sched_edit");
-  rdcart_cut_sched_edit->setGeometry(135,305,140,21);
-  rdcart_cut_sched_edit->setFont(line_edit_font);
-  rdcart_cut_sched_edit->setReadOnly(true);
-  QLabel *rdcart_cut_sched_label=new QLabel(rdcart_cut_sched_box,
-					    tr("Schedule Cuts:"),this,
-					    "rdcart_cut_sched_label");
-  rdcart_cut_sched_label->setGeometry(10,308,120,19);
-  rdcart_cut_sched_label->setFont(button_font);
-  rdcart_cut_sched_label->setAlignment(AlignRight|ShowPrefix);
-
   //
   // Synchronous Scheduling Policy
   //
@@ -493,9 +483,6 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
     //
     // Cut Widget
     //
-    rdcart_cut_sched_box->hide();
-    rdcart_cut_sched_edit->hide();
-    rdcart_cut_sched_label->hide();
     switch(rdcart_cart->type()) {
       case RDCart::Audio:
 	rdcart_audio_cart=new AudioCart(&rdcart_controls,rdcart_cart,
@@ -563,6 +550,8 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
       setText(QString().sprintf("%06d",rdcart_cart->number()));
     if(rdcart_group_box->count() == 0)
     {
+      PopulateGroupList();
+      /*
       QString sql=
 	QString().sprintf("select GROUP_NAME from USER_PERMS \
                            where USER_NAME=\"%s\" order by GROUP_NAME",
@@ -572,6 +561,7 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
 	rdcart_group_box->insertItem(q->value(0).toString());
       }
       delete q;
+      */
       for(int i=0;i<rdcart_group_box->count();i++) {
 	if(rdcart_group_box->text(i)==rdcart_cart->groupName()) {
 	  rdcart_group_box->setCurrentItem(i);
@@ -640,35 +630,22 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
     rdcart_usage_edit->
       setText(RDCart::usageText((RDCart::UsageCode)rdcart_usage_box->
 				currentItem()));
-    if(rdcart_cut_sched_box->count() == 0)
-    {
-      rdcart_cut_sched_box->insertItem(tr("Sequentially"));
-      rdcart_cut_sched_box->insertItem(tr("Randomly"));
-      rdcart_cut_sched_box->setCurrentItem(rdcart_cart->playOrder());
-    }
-    if(rdcart_cart->playOrder()==0) {
-      rdcart_cut_sched_edit->setText(tr("Sequentially"));
-    }
-    else {
-      rdcart_cut_sched_edit->setText(tr("Randomly"));
-    }
     rdcart_syncronous_box->setChecked(rdcart_cart->asyncronous());
   }
   else {//multi edit
     if(rdcart_group_box->count() == 0) {
       rdcart_group_box->insertItem("");
+      PopulateGroupList();
+      /*
       RDSqlQuery *q=new RDSqlQuery("select NAME from GROUPS");
       while(q->next()) {
         rdcart_group_box->insertItem(q->value(0).toString());
       }
       delete q;
+      */
       rdcart_group_box->setCurrentItem(0);
     }
     rdcart_usage_box->setCurrentItem(0);
-    rdcart_cut_sched_box->insertItem(tr(""));
-    rdcart_cut_sched_box->insertItem(tr("Sequentially"));
-    rdcart_cut_sched_box->insertItem(tr("Randomly"));
-    rdcart_cut_sched_box->setCurrentItem(0);
     rdcart_notes_button->hide();
   }
 
@@ -677,12 +654,10 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
   //
   if(modification_allowed) {
     rdcart_group_edit->hide();
-    rdcart_cut_sched_edit->hide();
     rdcart_usage_edit->hide();
   }
   else {
     rdcart_group_box->hide(); 
-    rdcart_cut_sched_box->hide();
     rdcart_usage_box->hide();
   }
   rdcart_syncronous_box->setEnabled(modification_allowed);
@@ -717,6 +692,14 @@ EditCart::EditCart(unsigned number,QString *path,bool new_cart,
 }
 
 
+EditCart::~EditCart()
+{
+  if(rdcart_cart!=NULL) {
+    delete rdcart_cart;
+  }
+}
+
+
 QSize EditCart::sizeHint() const
 {
   return QSize(640,750);
@@ -834,9 +817,6 @@ void EditCart::okData()
     rdcart_cart->setUserDefined(rdcart_controls.user_defined_edit->text());
     rdcart_cart->
       setUsageCode((RDCart::UsageCode)rdcart_usage_box->currentItem());
-    rdcart_cart->
-      setPlayOrder((RDCart::PlayOrder)rdcart_cut_sched_box->currentItem());
-    
     if(rdcart_cart->type()==RDCart::Macro) {
       rdcart_macro_cart->save();
       rdcart_cart->setAsyncronous(rdcart_syncronous_box->isChecked());
@@ -874,20 +854,21 @@ void EditCart::okData()
             rdcart_cart_medit->setClient(rdcart_controls.client_edit->text());
           if(!rdcart_controls.agency_edit->text().stripWhiteSpace().isEmpty())
             rdcart_cart_medit->setAgency(rdcart_controls.agency_edit->text());
-          if(!rdcart_controls.publisher_edit->text().stripWhiteSpace().isEmpty())
-            rdcart_cart_medit->setPublisher(rdcart_controls.publisher_edit->text());
+          if(!rdcart_controls.publisher_edit->text().stripWhiteSpace().
+	     isEmpty())
+            rdcart_cart_medit->
+	      setPublisher(rdcart_controls.publisher_edit->text());
           if(!rdcart_controls.composer_edit->text().stripWhiteSpace().isEmpty())
-            rdcart_cart_medit->setComposer(rdcart_controls.composer_edit->text());
-          if(!rdcart_controls.user_defined_edit->text().stripWhiteSpace().isEmpty())
-            rdcart_cart_medit->setUserDefined(rdcart_controls.user_defined_edit->text());
-          if(!rdcart_usage_box->currentText().stripWhiteSpace().isEmpty())          
+            rdcart_cart_medit->
+	      setComposer(rdcart_controls.composer_edit->text());
+          if(!rdcart_controls.user_defined_edit->text().
+	     stripWhiteSpace().isEmpty())
+            rdcart_cart_medit->
+	      setUserDefined(rdcart_controls.user_defined_edit->text());
+          if(!rdcart_usage_box->currentText().stripWhiteSpace().isEmpty())
             rdcart_cart_medit->
 	      setUsageCode((RDCart::UsageCode)(rdcart_usage_box->currentItem()-1));
-          if(!rdcart_cut_sched_box->currentText().stripWhiteSpace().isEmpty())          
-            rdcart_cart_medit->
-	      setPlayOrder((RDCart::PlayOrder)(rdcart_cut_sched_box->currentItem()-1));
           rdcart_cart_medit->updateSchedCodes(add_codes,remove_codes);
-	  
 	  delete rdcart_cart_medit; 
         }
       }
@@ -959,6 +940,9 @@ void EditCart::closeEvent(QCloseEvent *e)
 
 bool EditCart::ValidateLengths()
 {
+  return rdcart_cart->validateLengths(QTime().
+		     msecsTo(rdcart_controls.forced_length_edit->time()));
+  /*
   int maxlen=(int)(RD_TIMESCALE_MAX*
 		   (double)QTime().msecsTo(rdcart_controls.forced_length_edit->
 					   time()));
@@ -977,6 +961,7 @@ bool EditCart::ValidateLengths()
   delete q;
 
   return true;
+  */
 }
 
 
@@ -995,4 +980,15 @@ void EditCart::schedCodesData()
 }
 
 
-
+void EditCart::PopulateGroupList()
+{
+  QString sql=
+    QString().sprintf("select GROUP_NAME from USER_PERMS \
+                       where USER_NAME=\"%s\" order by GROUP_NAME",
+		      (const char *)lib_user->name());
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  while(q->next()) {
+    rdcart_group_box->insertItem(q->value(0).toString());
+  }
+  delete q;
+}
