@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_cart.h,v 1.27 2007-12-21 17:18:50 grauf Exp $
+//      $Id: edit_cart.h,v 1.30 2012/02/13 20:54:27 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -51,10 +51,12 @@ class EditCart : public QDialog
  public:
   EditCart(unsigned number,QString *path,bool new_cart,
 	   QWidget *parent=0,const char *name=0,QListView *lib_cart_list=NULL);
+  ~EditCart();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   
  private slots:
+  void notesData();
   void scriptData();
   void lengthChangedData(unsigned len);
   void okData();
@@ -68,6 +70,7 @@ class EditCart : public QDialog
   void closeEvent(QCloseEvent *e);
 
  private:
+  void PopulateGroupList();
   QListView *lib_cart_list_edit;
   bool ValidateLengths();
   RDCart *rdcart_cart;
@@ -76,8 +79,8 @@ class EditCart : public QDialog
   QComboBox *rdcart_group_box;
   QLineEdit *rdcart_group_edit;
   AudioControls rdcart_controls;
-  QComboBox *rdcart_cut_sched_box;
-  QLineEdit *rdcart_cut_sched_edit;
+  //  QComboBox *rdcart_cut_sched_box;
+  //  QLineEdit *rdcart_cut_sched_edit;
   QCheckBox *rdcart_syncronous_box;
   QLabel *rdcart_syncronous_label;
   QLineEdit *rdcart_start_date_edit;
@@ -95,6 +98,7 @@ class EditCart : public QDialog
   bool rdcart_new_cart;
   QComboBox *rdcart_usage_box;
   QLineEdit *rdcart_usage_edit;
+  QPushButton *rdcart_notes_button;
   QString sched_codes;
   QString add_codes;
   QString remove_codes;
