@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary.cpp,v 1.117 2012/01/12 15:33:15 cvs Exp $
+//      $Id: rdlibrary.cpp,v 1.117.4.2 2013/01/07 15:35:04 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -948,7 +948,7 @@ void MainWidget::RefreshList()
       sprintf(" where %s && %s",
 	      (const char *)RDAllCartSearchText(lib_filter_edit->text(),
 						schedcode,
-						lib_user->name()).utf8(),
+						lib_user->name(),true).utf8(),
 	      (const char *)type_filter);
   }
   else {
@@ -956,7 +956,7 @@ void MainWidget::RefreshList()
       sprintf(" where %s && %s",
 	      (const char *)RDCartSearchText(lib_filter_edit->text(),
 					     lib_group_box->currentText(),
-					     schedcode).
+					     schedcode,true).
 	      utf8(),
 	      (const char *)type_filter);
   }
@@ -1248,14 +1248,9 @@ void MainWidget::SetCaption(QString user)
   QString str1;
   QString str2;
 
-  str1=QString(tr("RDLibrary - Host:"));
-  str2=QString(tr(", User:"));
-  setCaption(QString().sprintf("%s %s, %s %s",
-			       (const char *)str1,
-			       (const char *)lib_config->stationName(),
-			       (const char *)str2,
-			       (const char *)user));
-  
+  str1=QString("RDLibrary")+" v"+VERSION+" - "+tr("Host")+":";
+  str2=tr("User")+":";
+  setCaption(str1+" "+lib_config->stationName()+", "+str2+" "+user);
 }
 
 
