@@ -703,11 +703,11 @@ Ação se Evento anterior estiver sendo executado</translation>
     <name>MainWidget</name>
     <message>
         <source>RDLogEdit - Host</source>
-        <translation>RDListas - Cliente</translation>
+        <translation type="obsolete">RDListas - Cliente</translation>
     </message>
     <message>
         <source>User: [Unknown]</source>
-        <translation>Usuário: [Desconhecido] </translation>
+        <translation type="obsolete">Usuário: [Desconhecido] </translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
@@ -847,6 +847,14 @@ Continuar?</translation>
 See your system administrator for an update!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VoiceTracker</name>
