@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: generate_log.cpp,v 1.32.2.1 2009/02/12 14:21:26 cvs Exp $
+//      $Id: generate_log.cpp,v 1.37 2011/05/03 19:46:29 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -329,7 +329,7 @@ void GenerateLog::createData()
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this,"svc");
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
   RDLog *log=new RDLog(logname);
-  if(log->exists() && cmdswitch==0) {
+  if(log->exists()) {
     str1=QString(tr("The log for"));
     str2=QString(tr("already exists.  Recreating it\nwill remove any merged Music or Traffic events.\n\nRecreate?"));
     if(QMessageBox::question(this,tr("Log Exists"),
@@ -342,7 +342,7 @@ void GenerateLog::createData()
       delete svc;
       return;
     }
-    if((tracks=log->completedTracks())>0 && cmdswitch==0) {
+    if((tracks=log->completedTracks())>0) {
       str1=QString(tr("This will also delete the"));
       str2=QString(tr("voice tracks associated with this log.\nContinue?"));
       if(QMessageBox::warning(this,tr("Tracks Exist"),
@@ -358,32 +358,28 @@ void GenerateLog::createData()
       }
     }
   }
-  log->removeTracks();
+  log->removeTracks(rdstation_conf,rduser);
 
-///////////  Scheduler
+  //
+  // Scheduler
+  //
   QString sql;
   RDSqlQuery *q;
 
   srand(QTime::currentTime().msec());
-
-
   sql=RDCreateStackTableSql(gen_service_box->currentText().replace(" ","_")); 
 
   q=new RDSqlQuery(sql);
   if(!q->isActive()) {
-    printf("SQL: %s\n",(const char *)sql);
-    printf("SQL Error: %s\n",(const char *)q->lastError().databaseText());
+    fprintf(stderr,"SQL: %s\n",(const char *)sql);
+    fprintf(stderr,"SQL Error: %s\n",
+	    (const char *)q->lastError().databaseText());
     delete q;
   }
   delete q;
 
-  if (cmdswitch==0) {
-    connect(svc,SIGNAL(generationProgress(int)),
-	    gen_progress_dialog,SLOT(setProgress(int)));
-  }
-  else {
-    printf("Generate Log\n");  
-  }
+  connect(svc,SIGNAL(generationProgress(int)),
+	  gen_progress_dialog,SLOT(setProgress(int)));
   svc->generateLog(gen_date_edit->date(),
 		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date()),
 		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date().
@@ -395,33 +391,18 @@ void GenerateLog::createData()
   //
   // Generate Exception Report
   //
-  if(cmdswitch==0) {
-    RDLogEvent *event=
-      new RDLogEvent(QString().sprintf("%s_LOG",(const char *)logname));
-    event->load();
-    if((event->validate(&report,gen_date_edit->date())==0)&&
-       unused_report.isEmpty()) {
-      QMessageBox::information(this,tr("No Errors"),tr("No exceptions found."));
-    }
-    else {
-      RDTextFile(report+"\n\n"+unused_report);
-    }
-    delete event;
-    UpdateControls();
+  RDLogEvent *event=
+    new RDLogEvent(QString().sprintf("%s_LOG",(const char *)logname));
+  event->load();
+  if((event->validate(&report,gen_date_edit->date())==0)&&
+     unused_report.isEmpty()) {
+    QMessageBox::information(this,tr("No Errors"),tr("No exceptions found."));
   }
   else {
-    RDLogEvent *event=
-      new RDLogEvent(QString().sprintf("%s_LOG",(const char *)logname));
-    event->load();
-    if((event->validate(&report,gen_date_edit->date())==0)&&
-       unused_report.isEmpty()) {
-      printf(tr("No exceptions found."));
-    }
-    else {
-      printf("%s\n\n%s",(const char*)report,(const char*)unused_report);
-    }
-    delete event;
+    RDTextFile(report+"\n\n"+unused_report);
   }
+  delete event;
+  UpdateControls();
 }
 
 
@@ -433,7 +414,7 @@ void GenerateLog::musicData()
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
   RDLog *log=new RDLog(logname);
   if(((log->linkState(RDLog::SourceMusic)==RDLog::LinkDone)||
-     (log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone)) && cmdswitch==0) {
+      (log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone))) {
     QString str1=QString(tr("The log for"));
     QString str2=QString(tr("already contains merged music and/or traffic data.\nRemerging it will remove this data.  Remerge?"));
     if(QMessageBox::question(this,tr("Music Exists"),
@@ -446,7 +427,7 @@ void GenerateLog::musicData()
       delete svc;
       return;
     }
-    if((tracks=log->completedTracks())>0 && cmdswitch==0) {
+    if((tracks=log->completedTracks())>0) {
       str1=QString(tr("This will also delete the"));
       str2=QString(tr("voice tracks associated with this log.\nContinue?"));
       if(QMessageBox::warning(this,tr("Tracks Exist"),
@@ -461,32 +442,20 @@ void GenerateLog::musicData()
 	return;
       }
     }
-    log->removeTracks();
+    log->removeTracks(rdstation_conf,rduser);
     svc->clearLogLinks(RDSvc::Traffic,gen_date_edit->date(),logname);
     svc->clearLogLinks(RDSvc::Music,gen_date_edit->date(),logname);
   }
-  // return;
-  if (cmdswitch==0)
   connect(svc,SIGNAL(generationProgress(int)),
 	  gen_progress_dialog,SLOT(setProgress(int)));
-  else
-    printf("Merge Music\n");  
   QString report;
   svc->linkLog(RDSvc::Music,gen_date_edit->date(),logname,&report);
   delete log;
   delete svc;
-  if (cmdswitch==0)
-    {
   if(!report.isEmpty()) {
     RDTextFile(report);
   }
   UpdateControls();
-    }
-  else {
-    if(!report.isEmpty()) {
-      printf("%s\n",(const char*)report);
-    }
-  }
 }
 
 
@@ -495,7 +464,7 @@ void GenerateLog::trafficData()
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this,"svc");
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
   RDLog *log=new RDLog(logname);
-  if((log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone) && cmdswitch==0) {
+  if((log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone)) {
     QString str1=QString(tr("The log for"));
     QString str2=QString(tr("already contains merged traffic data.  Remerging it\nwill remove this data.  Remerge?"));
     if(QMessageBox::question(this,tr("Traffic Exists"),
@@ -510,30 +479,20 @@ void GenerateLog::trafficData()
     }
     svc->clearLogLinks(RDSvc::Traffic,gen_date_edit->date(),logname);
   }
-  // return;
-  if (cmdswitch==0)
   connect(svc,SIGNAL(generationProgress(int)),
 	  gen_progress_dialog,SLOT(setProgress(int)));
-  else
-    printf("Merge Traffic\n");  
 
   QString report;
   svc->linkLog(RDSvc::Traffic,gen_date_edit->date(),logname,&report);
   delete log;
   delete svc;
-  if (cmdswitch==0) {
   if(!report.isEmpty()) {
     RDTextFile(report);
   }
   UpdateControls();
-  }
-  else {
-    if(!report.isEmpty()) {
-      printf("%s\n",(const char*)report);
-    }
-  }
 }
 
+
 void GenerateLog::fileScanData()
 {
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this,"svc");
