@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: vguest.cpp,v 1.30.2.1 2009/02/10 16:19:33 cvs Exp $
+//      $Id: vguest.cpp,v 1.36 2010/08/03 23:39:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@
 
 
 VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
-  : QObject(parent,name)
+  : Switcher(matrix,parent,name)
 {
   RDTty *tty;
   QString sql;
@@ -213,6 +213,36 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
 }
 
 
+RDMatrix::Type VGuest::type()
+{
+  return RDMatrix::LogitekVguest;
+}
+
+
+unsigned VGuest::gpiQuantity()
+{
+  return vguest_gpis;
+}
+
+
+unsigned VGuest::gpoQuantity()
+{
+  return vguest_gpos;
+}
+
+
+bool VGuest::primaryTtyActive()
+{
+  return vguest_porttype[0]==RDMatrix::TtyPort;
+}
+
+
+bool VGuest::secondaryTtyActive()
+{
+  return vguest_porttype[1]==RDMatrix::TtyPort;
+}
+
+
 void VGuest::processCommand(RDMacro *cmd)
 {
   char buffer[VGUEST_MAX_COMMAND_LENGTH];
@@ -309,7 +339,7 @@ void VGuest::processCommand(RDMacro *cmd)
 	  emit rmlEcho(cmd);
 	  return;
 	}
-	switch(cmd_byte) {
+	switch(0xFF&cmd_byte) {
 	    case 0x51:
 	      sprintf(buffer,"\x02\x07\x51%c%c%c%c%c%c",
 		      vguest_relays_engine_nums[cmd->arg(2).toInt()-1],
@@ -351,11 +381,6 @@ void VGuest::processCommand(RDMacro *cmd)
 }
 
 
-void VGuest::processStatus(char *buf,int size)
-{
-}
-
-
 void VGuest::ipConnect(int id)
 {
   if(!vguest_ipaddress[id].isNull()) {
@@ -490,9 +515,10 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
   QString str;
   int linenum;
 
-  // LogLine(QString().sprintf("RCVD: %s",(const char *)RenderCommand(cmd,len)));
+  // LogLine(RDConfig::LogNotice,
+  //QString().sprintf("RCVD: %s",(const char *)RenderCommand(cmd,len)));
 
-  switch(cmd[2]) {
+  switch(0xFF&cmd[2]) {
       case 0xF9:   // Username/Password Query
 	buffer[0]=0x02;
 	buffer[1]=0x22;
@@ -505,7 +531,7 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 	break;
 
       case 0xF0:   // Connect Status
-	switch(cmd[3]) {
+	switch(0xFF&cmd[3]) {
 	    case 0x0A:  // Valid connection
 	    case 0x14:
 	      LogLine(RDConfig::LogInfo,QString().sprintf(
