@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsoftkeys.cpp,v 1.5 2008-07-26 00:01:43 fredg Exp $
+//      $Id: rdsoftkeys.cpp,v 1.7.8.1 2013/01/07 15:35:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -52,12 +52,6 @@
 MainWidget::MainWidget(QWidget *parent,const char *name)
   : QMainWindow(parent,name)
 {
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-#ifndef WIN32
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-#endif
   key_ysize=70;
 
   //
@@ -83,7 +77,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   QFont label_font("Helvetica",18,QFont::Bold);
   label_font.setPixelSize(18);
 
-  setCaption("RDSoftKeys");
+  setCaption(QString("RDSoftKeys")+" v"+VERSION);
 
   //
   // Create And Set Icon
