@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rmlsend.cpp,v 1.5 2008/04/01 18:27:36 fredg Exp $
+//      $Id: rmlsend.cpp,v 1.7.8.2 2013/03/13 20:10:40 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -75,13 +75,6 @@ RDCmdSwitch *rdcmdswitch=NULL;
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QMainWindow(parent,name)
 {
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-#ifndef WIN32
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-#endif  // WIN32
-
   //
   // Set Window Size
   //
@@ -93,9 +86,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Create Fonts
   //
-  main_font=QFont("Helvetica",12,QFont::Bold);
+  QFont font("Helvetica",10,QFont::Normal);
+  font.setPixelSize(10);
+  setFont(font);
+  QFont main_font("Helvetica",12,QFont::Bold);
   main_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",10,QFont::Bold);
+  QFont label_font("Helvetica",10,QFont::Bold);
   label_font.setPixelSize(10);
 
   //
@@ -104,7 +100,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   rivendell_map=new QPixmap(rivendell_xpm);
   setIcon(*rivendell_map);
 
-  setCaption(tr("RMLSend - Macro Command Utility"));
+  setCaption(QString("RMLSend")+" v"+VERSION+" - "+tr("Macro Command Utility"));
 
   host=new QLineEdit(this,"host");
   host->setGeometry(80,10,180,25);
@@ -535,7 +531,7 @@ int main(int argc,char *argv[])
 			      readEntry("/Rivendell/InstallDir"));
     qt_path=tr_path;
 #else
-    tr_path=QString(PREFIX)+QString("/share/srlabs/");
+    tr_path=QString(PREFIX)+QString("/share/rivendell/");
     qt_path=QString(QTDIR)+QString("/translation/");
 #endif  // WIN32
     QTranslator qt(0);
@@ -545,7 +541,7 @@ int main(int argc,char *argv[])
     QTranslator rd(0);
     rd.load(tr_path+QString("librd_")+QTextCodec::locale(),".");
     a.installTranslator(&rd);
-    
+
     QTranslator rdhpi(0);
     rdhpi.load(tr_path+QString("librdhpi_")+QTextCodec::locale(),".");
     a.installTranslator(&rdhpi);
@@ -553,7 +549,7 @@ int main(int argc,char *argv[])
     QTranslator tr(0);
     tr.load(tr_path+QString("rmlsend_")+QTextCodec::locale(),".");
     a.installTranslator(&tr);
-    
+
     //
     // Start Event Loop
     //
