@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: import.cpp,v 1.7 2011/04/01 21:40:59 cvs Exp $
+//      $Id: import.cpp,v 1.12.2.1 2013/02/27 21:21:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <syslog.h>
 
 #include <rdformpost.h>
 #include <rdweb.h>
@@ -40,56 +39,57 @@ void Xport::Import()
 {
   unsigned length_deviation=0;
   unsigned msecs;
+  int resp_code=0;
 
   //
   // Verify Post
   //
   int cartnum=0;
   if(!xport_post->getValue("CART_NUMBER",&cartnum)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
   int cutnum=0;
   if(!xport_post->getValue("CUT_NUMBER",&cutnum)) {
-    RDCgiError("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400);
   }
   int channels=0;
   if(!xport_post->getValue("CHANNELS",&channels)) {
-    RDCgiError("Missing CHANNELS",400);
+    XmlExit("Missing CHANNELS",400);
   }
   int normalization_level=0;
   if(!xport_post->getValue("NORMALIZATION_LEVEL",&normalization_level)) {
-    RDCgiError("Missing NORMALIZATION_LEVEL",400);
+    XmlExit("Missing NORMALIZATION_LEVEL",400);
   }
   int autotrim_level=0;
   if(!xport_post->getValue("AUTOTRIM_LEVEL",&autotrim_level)) {
-    RDCgiError("Missing AUTOTRIM_LEVEL",400);
+    XmlExit("Missing AUTOTRIM_LEVEL",400);
   }
   int use_metadata=0;
   if(!xport_post->getValue("USE_METADATA",&use_metadata)) {
-    RDCgiError("Missing USE_METADATA",400);
+    XmlExit("Missing USE_METADATA",400);
   }
   QString filename;
   if(!xport_post->getValue("FILENAME",&filename)) {
-    RDCgiError("Missing FILENAME",400);
+    XmlExit("Missing FILENAME",400);
   }
   if(!RDCart::exists(cartnum)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(!RDCut::exists(cartnum,cutnum)) {
-    RDCgiError("No such cut",404);
+    XmlExit("No such cut",404);
   }
   if(!xport_post->isFile("FILENAME")) {
-    RDCgiError("Missing file data",400);
+    XmlExit("Missing file data",400);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cartnum)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(!xport_user->editAudio()) {
-    RDCgiError("Unauthorized",401);
+    XmlExit("Unauthorized",401);
   }
 
   //
@@ -115,11 +115,14 @@ void Xport::Import()
   RDWaveFile *wave=new RDWaveFile(filename);
   if(!wave->openWave()) {
     delete wave;
+    XmlExit("Format Not Supported",415);
+    /*
     printf("Content-type: text/html\n");
     printf("Status: %d\n",415);
     printf("\n");
     printf("Format Not Supported\n");
     exit(0);
+    */
   }
   msecs=wave->getExtTimeLength();
   delete wave;
@@ -130,11 +133,11 @@ void Xport::Import()
   RDAudioConvert::ErrorCode conv_err=conv->convert();
   switch(conv_err) {
   case RDAudioConvert::ErrorOk:
+    cut->checkInRecording(xport_config->stationName(),settings,msecs);
     if(use_metadata>0) {
       cart->setMetadata(conv->sourceWaveData());
       cut->setMetadata(conv->sourceWaveData());
     }
-    cut->checkInRecording(xport_config->stationName(),settings,msecs);
     if(autotrim_level!=0) {
       cut->autoTrim(RDCut::AudioBoth,100*autotrim_level);
     }
@@ -142,52 +145,27 @@ void Xport::Import()
     cart->resetRotation();
     cart->calculateAverageLength(&length_deviation);
     cart->setLengthDeviation(length_deviation);
-    printf("Content-type: text/html\n");
-    printf("Status: %d\n",200);
-    printf("\n");
-    printf("OK\n");
+    resp_code=200;
     break;
 
   case RDAudioConvert::ErrorFormatNotSupported:
-    printf("Content-type: text/html\n");
-    printf("Status: %d\n",415);
-    printf("\n");
-    printf("Format Not Supported\n");
-    break;
-
   case RDAudioConvert::ErrorInvalidSettings:
-    printf("Content-type: text/html\n");
-    printf("Status: %d\n",415);
-    printf("\n");
-    printf("Invalid Export Settings\n");
+    resp_code=415;
     break;
 
   case RDAudioConvert::ErrorNoSource:
-    printf("Content-type: text/html\n");
-    printf("Status: %d\n",500);
-    printf("\n");
-    printf("No Source Error\n");
-    break;
-
   case RDAudioConvert::ErrorNoDestination:
-    printf("Content-type: text/html\n");
-    printf("Status: %d\n",500);
-    printf("\n");
-    printf("No Destination Error\n");
-    break;
-
   case RDAudioConvert::ErrorInvalidSource:
-    printf("Content-type: text/html\n");
-    printf("Status: %d\n",500);
-    printf("\n");
-    printf("Invalid Source Error\n");
+  case RDAudioConvert::ErrorInternal:
+  case RDAudioConvert::ErrorNoSpace:
+  case RDAudioConvert::ErrorNoDisc:
+  case RDAudioConvert::ErrorNoTrack:
+  case RDAudioConvert::ErrorInvalidSpeed:
+    resp_code=500;
     break;
 
-  case RDAudioConvert::ErrorInternal:
-    printf("Content-type: text/html\n");
-    printf("Status: %d\n",500);
-    printf("\n");
-    printf("Internal Server Error\n");
+  case RDAudioConvert::ErrorFormatError:
+    resp_code=400;
     break;
   }
   delete conv;
@@ -195,4 +173,5 @@ void Xport::Import()
   delete conf;
   delete cut;
   delete cart;
+  XmlExit(RDAudioConvert::errorText(conv_err),resp_code,conv_err);
 }
